@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.44.4.1 2004/10/30 17:49:42 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.48 2004/11/16 14:21:23 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-embed.h"
 
@@ -55,9 +53,9 @@ ephy_embed_chrome_get_type (void)
 GType
 ephy_embed_get_type (void)
 {
-	static GType ephy_embed_type = 0;
+	static GType type = 0;
 
-	if (ephy_embed_type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -66,13 +64,12 @@ ephy_embed_get_type (void)
 			NULL,
 		};
 
-		ephy_embed_type = g_type_register_static (G_TYPE_INTERFACE,
-							  "EphyEmbed",
-							  &our_info,
-							  (GTypeFlags)0);
+		type = g_type_register_static (G_TYPE_INTERFACE,
+					       "EphyEmbed",
+					       &our_info, (GTypeFlags)0);
 	}
 
-	return ephy_embed_type;
+	return type;
 }
 
 static void
@@ -670,6 +667,19 @@ ephy_embed_get_security_level (EphyEmbed *embed,
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
 	iface->get_security_level (embed, level, description);
 }
+/**
+ * ephy_embed_show_page_certificate:
+ * @embed: an #EphyEmbed
+ *
+ * Shows a dialogue displaying the certificate of the currently loaded page
+ * of @embed, if it was loaded over a secure connection; else does nothing.
+ **/
+void
+ephy_embed_show_page_certificate (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->show_page_certificate (embed);
+}
 
 /**
  * ephy_embed_find_set_properties:
