@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.48 2004/05/20 18:07:12 chpe Exp $
+ *  $Id: ephy-history.c,v 1.52 2004/11/11 14:19:17 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-history.h"
 #include "ephy-file-helpers.h"
@@ -88,7 +86,7 @@ ephy_history_get_type (void)
 {
         static GType type = 0;
 
-        if (type == 0)
+        if (G_UNLIKELY (type == 0))
         {
                 static const GTypeInfo our_info =
                 {
@@ -231,7 +229,7 @@ remove_obsolete_pages (EphyHistory *eb)
         g_date_set_time (&current_date, time (NULL));
 
 	children = ephy_node_get_children (eb->priv->pages);
-	for (i = children->len -1; i >= 0; i--)
+	for (i = (int) children->len - 1; i >= 0; i--)
 	{
 		EphyNode *kid;
 
@@ -435,6 +433,24 @@ page_removed_from_host_cb (EphyNode *node,
 	}
 }
 
+static void
+remove_pages_from_host_cb (EphyNode *host,
+			   EphyHistory *eh)
+{
+	GPtrArray *children;
+	EphyNode *site;
+	int i;
+
+	children = ephy_node_get_children (host);
+
+	for (i = (int) children->len - 1; i >= 0; i--)
+	{
+		site = g_ptr_array_index (children, i);
+
+		ephy_node_unref (site);
+	}
+}
+
 static void
 connect_page_removed_from_host (char *url,
                                 EphyNode *node,
@@ -446,6 +462,10 @@ connect_page_removed_from_host (char *url,
 					 EPHY_NODE_CHILD_REMOVED,
 				         (EphyNodeCallback) page_removed_from_host_cb,
 					 G_OBJECT (eb));
+	ephy_node_signal_connect_object (node,
+					 EPHY_NODE_DESTROY,
+					 (EphyNodeCallback) remove_pages_from_host_cb,
+					 G_OBJECT (eb));
 }
 
 static void
@@ -706,6 +726,10 @@ ephy_history_get_host (EphyHistory *eh, const char *url)
 						 EPHY_NODE_CHILD_REMOVED,
 					         (EphyNodeCallback) page_removed_from_host_cb,
 						 G_OBJECT (eh));
+		ephy_node_signal_connect_object (host,
+						 EPHY_NODE_DESTROY,
+						 (EphyNodeCallback) remove_pages_from_host_cb,
+						 G_OBJECT (eh));
 
 		g_value_init (&value, G_TYPE_STRING);
 		g_value_set_string (&value, host_name);
