@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.17.4.5 2005/05/30 17:01:28 chpe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.25 2004/11/19 20:24:31 chpe Exp $
  */
 
 /*
@@ -28,11 +28,7 @@
 
 #include "mozilla-config.h"
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
-
-#ifdef HAVE_MOZILLA_PSM
 
 #include "EphyUtils.h"
 
@@ -221,6 +217,8 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      NULL);
 
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
 	higgy_setup_dialog (GTK_DIALOG (dialog), 
 			    GTK_STOCK_DIALOG_WARNING, &label, &vbox);
 
@@ -346,7 +344,7 @@ GtkNSSDialogs::ConfirmUnknownIssuer (nsIInterfaceRequestor *ctx,
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", cCommonName.get());
 
 	secondary = g_strdup_printf
-		           (_("Your browser was unable to trust %s. "
+		           (_("It was not possible to automatically trust %s. "
 			      "It is possible that someone is intercepting your "
 			      "communication to obtain your confidential information."),
 			      ttCommonName);
@@ -489,6 +487,8 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 					      GTK_RESPONSE_OK,
 					      NULL);
 
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_ERROR,
 			    &label, NULL);
 
@@ -554,6 +554,8 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 					      _("_Trust CA"),	GTK_RESPONSE_ACCEPT,
 					      NULL);
 
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_WARNING,
 			    &label, &content_vbox);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
@@ -623,7 +625,7 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 
 		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_software)))
 		{
-			*_trust |= nsIX509CertDB::TRUSTED_OBJSIGN;
+			*_trust |= nsIX509CertDB::TRUSTED_SSL;
 		}
 		*_retval = PR_TRUE;
 	}
@@ -649,6 +651,8 @@ GtkNSSDialogs::NotifyCACertExists (nsIInterfaceRequestor *ctx)
 					      GTK_RESPONSE_OK,
 					      NULL);
 
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_ERROR,
 			    &label, NULL);
 
@@ -770,6 +774,8 @@ GtkNSSDialogs::SetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 					      GTK_RESPONSE_CANCEL,
 					      NULL);
 
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_QUESTION,
 			    &label, &vbox);
 
@@ -880,6 +886,8 @@ GtkNSSDialogs::GetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 					      _("I_mport Certificate"), GTK_RESPONSE_OK,
 					      NULL);
 
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_QUESTION,
 			    &label, &vbox);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
@@ -961,6 +969,8 @@ GtkNSSDialogs::CrlImportStatusDialog(nsIInterfaceRequestor *ctx, nsICRLInfo *crl
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
 
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_INFO,
 			    &label, &vbox);
 
@@ -1303,6 +1313,8 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 	gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(gparent));
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Certificate Properties"));
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
 
@@ -1451,5 +1463,3 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 	gtk_widget_destroy (dialog);
 	return NS_OK;
 }
-
-#endif
