@@ -16,19 +16,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: PrintingPromptService.cpp,v 1.16 2004/07/03 22:52:28 xan Exp $
+ *  $Id: PrintingPromptService.cpp,v 1.19 2004/11/02 20:56:55 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
+#include "mozilla-config.h"
+
 #include "config.h"
-#endif
 
 #include <gtk/gtkdialog.h>
 
 #include "print-dialog.h"
 #include "ephy-embed.h"
 #include "ephy-command-manager.h"
-#include "MozillaPrivate.h"
+#include "EphyUtils.h"
 #include "PrintingPromptService.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
@@ -61,13 +61,13 @@ NS_IMETHODIMP GPrintingPromptService::ShowPrintDialog(nsIDOMWindow *parent, nsIW
 		return NS_ERROR_ABORT;
 	}
 
-	EphyEmbed *embed = EPHY_EMBED (MozillaFindEmbed (parent));
+	EphyEmbed *embed = EPHY_EMBED (EphyUtils::FindEmbed (parent));
 	NS_ENSURE_TRUE (embed, NS_ERROR_FAILURE);
 
 	if (!(eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINT_SETUP) ||
 	      eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_COMMAND_LINE)))
 	{
-		GtkWidget *gtkParent = MozillaFindGtkParent(parent);
+		GtkWidget *gtkParent = EphyUtils::FindGtkParent(parent);
 		NS_ENSURE_TRUE (gtkParent, NS_ERROR_FAILURE);
 
 		dialog = ephy_print_dialog_new (gtkParent, embed);
@@ -94,7 +94,7 @@ NS_IMETHODIMP GPrintingPromptService::ShowPrintDialog(nsIDOMWindow *parent, nsIW
 		info->pages = 0;
 	}
 
-	MozillaCollatePrintSettings (info, printSettings, FALSE);
+	EphyUtils::CollatePrintSettings (info, printSettings, FALSE);
 
 	ephy_print_info_free (info);
 
