@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: print-dialog.c,v 1.36 2004/10/27 20:03:56 chpe Exp $
+ *  $Id: print-dialog.c,v 1.37 2004/11/02 20:56:55 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "print-dialog.h"
 #include "ephy-embed-single.h"
