@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2002-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2002-2004 Marco Pesenti Gritti
+ *  Copyright (C) 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,8 +15,12 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: egg-toolbars-model.c,v 1.29 2004/11/02 20:57:20 chpe Exp $
  */
 
+#include "config.h"
+
 #include "egg-toolbars-model.h"
 #include "eggmarshalers.h"
 
@@ -54,7 +59,7 @@ typedef struct
   gboolean separator;
 } EggToolbarsItem;
 
-static guint egg_toolbars_model_signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL] = { 0 };
 
 static GObjectClass *parent_class = NULL;
 
@@ -68,9 +73,9 @@ struct EggToolbarsModelPrivate
 GType
 egg_toolbars_model_get_type (void)
 {
-  static GType egg_toolbars_model_type = 0;
+  static GType type = 0;
 
-  if (egg_toolbars_model_type == 0)
+  if (G_UNLIKELY (type == 0))
     {
       static const GTypeInfo our_info = {
 	sizeof (EggToolbarsModelClass),
@@ -84,13 +89,12 @@ egg_toolbars_model_get_type (void)
 	(GInstanceInitFunc) egg_toolbars_model_init
       };
 
-      egg_toolbars_model_type = g_type_register_static (G_TYPE_OBJECT,
-							"EggToolbarsModel",
-							&our_info, 0);
+      type = g_type_register_static (G_TYPE_OBJECT,
+				     "EggToolbarsModel",
+				     &our_info, 0);
     }
 
-  return egg_toolbars_model_type;
-
+  return type;
 }
 
 static xmlDocPtr
@@ -218,7 +222,7 @@ toolbars_toolbar_new (const char *name)
 {
   EggToolbarsToolbar *toolbar;
 
-  toolbar = g_new0 (EggToolbarsToolbar, 1);
+  toolbar = g_new (EggToolbarsToolbar, 1);
   toolbar->name = g_strdup (name);
   toolbar->flags = 0;
 
@@ -235,7 +239,7 @@ toolbars_item_new (const char *id,
   g_return_val_if_fail (id != NULL, NULL);
   g_return_val_if_fail (type != NULL, NULL);
 
-  item = g_new0 (EggToolbarsItem, 1);
+  item = g_new (EggToolbarsItem, 1);
   item->id = g_strdup (id);
   item->type = g_strdup (type);
   item->separator = separator;
@@ -244,22 +248,26 @@ toolbars_item_new (const char *id,
 }
 
 static void
-free_toolbar_node (EggToolbarsToolbar *toolbar)
+free_toolbar_node (GNode *toolbar_node)
 {
-  g_return_if_fail (toolbar != NULL);
+  EggToolbarsToolbar *toolbar = toolbar_node->data;
 
   g_free (toolbar->name);
   g_free (toolbar);
+
+  g_node_destroy (toolbar_node);
 }
 
 static void
-free_item_node (EggToolbarsItem *item)
+free_item_node (GNode *item_node)
 {
-  g_return_if_fail (item != NULL);
+  EggToolbarsItem *item = item_node->data;
 
   g_free (item->id);
   g_free (item->type);
   g_free (item);
+
+  g_node_destroy (item_node);
 }
 
 EggTbModelFlags
@@ -279,8 +287,8 @@ egg_toolbars_model_get_flags (EggToolbarsModel *t,
 
 void
 egg_toolbars_model_set_flags (EggToolbarsModel *t,
-			      EggTbModelFlags   flags,
-			      int               toolbar_position)
+			      int               toolbar_position,
+			      EggTbModelFlags   flags)
 {
   GNode *toolbar_node;
   EggToolbarsToolbar *toolbar;
@@ -292,7 +300,7 @@ egg_toolbars_model_set_flags (EggToolbarsModel *t,
 
   toolbar->flags = flags;
 
-  g_signal_emit (G_OBJECT (t), egg_toolbars_model_signals[TOOLBAR_CHANGED],
+  g_signal_emit (G_OBJECT (t), signals[TOOLBAR_CHANGED],
 		 0, toolbar_position);
 }
 
@@ -315,7 +323,7 @@ egg_toolbars_model_add_separator (EggToolbarsModel *t,
 
   real_position = g_node_child_position (parent_node, node);
 
-  g_signal_emit (G_OBJECT (t), egg_toolbars_model_signals[ITEM_ADDED], 0,
+  g_signal_emit (G_OBJECT (t), signals[ITEM_ADDED], 0,
 		 toolbar_position, real_position);
 }
 
@@ -342,7 +350,7 @@ impl_add_item (EggToolbarsModel    *t,
 
   real_position = g_node_child_position (parent_node, node);
 
-  g_signal_emit (G_OBJECT (t), egg_toolbars_model_signals[ITEM_ADDED], 0,
+  g_signal_emit (G_OBJECT (t), signals[ITEM_ADDED], 0,
 		 toolbar_position, real_position);
 
   return TRUE;
@@ -403,7 +411,7 @@ egg_toolbars_model_add_toolbar (EggToolbarsModel *t,
 
   real_position = g_node_child_position (t->priv->toolbars, node);
 
-  g_signal_emit (G_OBJECT (t), egg_toolbars_model_signals[TOOLBAR_ADDED],
+  g_signal_emit (G_OBJECT (t), signals[TOOLBAR_ADDED],
 		 0, real_position);
 
   return g_node_child_position (t->priv->toolbars, node);
@@ -428,7 +436,8 @@ parse_toolbars (EggToolbarsModel *t,
 	  style = xmlGetProp (child, "style");
 	  if (style && xmlStrEqual (style, "icons-only"))
 	    {
-	      egg_toolbars_model_set_flags (t, EGG_TB_MODEL_ICONS_ONLY, 0);
+	      /* FIXME: use toolbar position instead of 0 */
+	      egg_toolbars_model_set_flags (t, 0, EGG_TB_MODEL_ICONS_ONLY);
 	    }
 	  xmlFree (style);
 
@@ -534,42 +543,42 @@ egg_toolbars_model_class_init (EggToolbarsModelClass *klass)
   klass->get_item_data = impl_get_item_data;
   klass->get_item_type = impl_get_item_type;
 
-  egg_toolbars_model_signals[ITEM_ADDED] =
+  signals[ITEM_ADDED] =
     g_signal_new ("item_added",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (EggToolbarsModelClass, item_added),
 		  NULL, NULL, _egg_marshal_VOID__INT_INT,
 		  G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
-  egg_toolbars_model_signals[TOOLBAR_ADDED] =
+  signals[TOOLBAR_ADDED] =
     g_signal_new ("toolbar_added",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (EggToolbarsModelClass, toolbar_added),
 		  NULL, NULL, g_cclosure_marshal_VOID__INT,
 		  G_TYPE_NONE, 1, G_TYPE_INT);
-  egg_toolbars_model_signals[ITEM_REMOVED] =
+  signals[ITEM_REMOVED] =
     g_signal_new ("item_removed",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (EggToolbarsModelClass, item_removed),
 		  NULL, NULL, _egg_marshal_VOID__INT_INT,
 		  G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
-  egg_toolbars_model_signals[TOOLBAR_REMOVED] =
+  signals[TOOLBAR_REMOVED] =
     g_signal_new ("toolbar_removed",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (EggToolbarsModelClass, toolbar_removed),
 		  NULL, NULL, g_cclosure_marshal_VOID__INT,
 		  G_TYPE_NONE, 1, G_TYPE_INT);
-  egg_toolbars_model_signals[TOOLBAR_CHANGED] =
+  signals[TOOLBAR_CHANGED] =
     g_signal_new ("toolbar_changed",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (EggToolbarsModelClass, toolbar_changed),
 		  NULL, NULL, g_cclosure_marshal_VOID__INT,
 		  G_TYPE_NONE, 1, G_TYPE_INT);
-  egg_toolbars_model_signals[GET_ITEM_TYPE] =
+  signals[GET_ITEM_TYPE] =
     g_signal_new ("get_item_type",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
@@ -577,7 +586,7 @@ egg_toolbars_model_class_init (EggToolbarsModelClass *klass)
 		  _egg_accumulator_STRING, NULL,
 		  _egg_marshal_STRING__POINTER,
 		  G_TYPE_STRING, 1, G_TYPE_POINTER);
-  egg_toolbars_model_signals[GET_ITEM_ID] =
+  signals[GET_ITEM_ID] =
     g_signal_new ("get_item_id",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
@@ -585,7 +594,7 @@ egg_toolbars_model_class_init (EggToolbarsModelClass *klass)
 		  _egg_accumulator_STRING, NULL,
 		  _egg_marshal_STRING__STRING_STRING,
 		  G_TYPE_STRING, 2, G_TYPE_STRING, G_TYPE_STRING);
-  egg_toolbars_model_signals[GET_ITEM_DATA] =
+  signals[GET_ITEM_DATA] =
     g_signal_new ("get_item_data",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
@@ -605,12 +614,21 @@ egg_toolbars_model_init (EggToolbarsModel *t)
   t->priv->toolbars = g_node_new (NULL);
 }
 
+static void
+free_toolbar (GNode *toolbar_node)
+{
+  g_node_children_foreach (toolbar_node, G_TRAVERSE_ALL,
+    			   (GNodeForeachFunc) free_item_node, NULL);
+  free_toolbar_node (toolbar_node);
+}
+
 static void
 egg_toolbars_model_finalize (GObject *object)
 {
   EggToolbarsModel *t = EGG_TOOLBARS_MODEL (object);
 
-  /* FIXME free nodes */
+  g_node_children_foreach (t->priv->toolbars, G_TRAVERSE_ALL,
+    			   (GNodeForeachFunc) free_toolbar, NULL);
   g_node_destroy (t->priv->toolbars);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -638,10 +656,9 @@ egg_toolbars_model_remove_toolbar (EggToolbarsModel   *t,
       node = g_node_nth_child (t->priv->toolbars, position);
       g_return_if_fail (node != NULL);
 
-      free_toolbar_node (node->data);
-      g_node_destroy (node);
+      free_toolbar_node (node);
 
-      g_signal_emit (G_OBJECT (t), egg_toolbars_model_signals[TOOLBAR_REMOVED],
+      g_signal_emit (G_OBJECT (t), signals[TOOLBAR_REMOVED],
 		     0, position);
     }
 }
@@ -661,10 +678,9 @@ egg_toolbars_model_remove_item (EggToolbarsModel *t,
   node = g_node_nth_child (toolbar, position);
   g_return_if_fail (node != NULL);
 
-  free_item_node (node->data);
-  g_node_destroy (node);
+  free_item_node (node);
 
-  g_signal_emit (G_OBJECT (t), egg_toolbars_model_signals[ITEM_REMOVED], 0,
+  g_signal_emit (G_OBJECT (t), signals[ITEM_REMOVED], 0,
 		 toolbar_position, position);
 }
 
@@ -690,12 +706,12 @@ egg_toolbars_model_move_item (EggToolbarsModel *t,
 
   g_node_unlink (node);
 
-  g_signal_emit (G_OBJECT (t), egg_toolbars_model_signals[ITEM_REMOVED], 0,
+  g_signal_emit (G_OBJECT (t), signals[ITEM_REMOVED], 0,
 		 toolbar_position, position);
 
   g_node_insert (new_toolbar, new_position, node);
 
-  g_signal_emit (G_OBJECT (t), egg_toolbars_model_signals[ITEM_ADDED], 0,
+  g_signal_emit (G_OBJECT (t), signals[ITEM_ADDED], 0,
 		 new_toolbar_position, new_position);
 }
 
@@ -783,7 +799,7 @@ egg_toolbars_model_get_item_id (EggToolbarsModel *t,
 {
   char *retval;
 
-  g_signal_emit (t, egg_toolbars_model_signals[GET_ITEM_ID], 0, type, name, &retval);
+  g_signal_emit (t, signals[GET_ITEM_ID], 0, type, name, &retval);
 
   return retval;
 }
@@ -795,7 +811,7 @@ egg_toolbars_model_get_item_data (EggToolbarsModel *t,
 {
   char *retval;
 
-  g_signal_emit (t, egg_toolbars_model_signals[GET_ITEM_DATA], 0, type, id, &retval);
+  g_signal_emit (t, signals[GET_ITEM_DATA], 0, type, id, &retval);
 
   return retval;
 }
@@ -806,7 +822,7 @@ egg_toolbars_model_get_item_type (EggToolbarsModel *t,
 {
   char *retval;
 
-  g_signal_emit (t, egg_toolbars_model_signals[GET_ITEM_TYPE], 0, type, &retval);
+  g_signal_emit (t, signals[GET_ITEM_TYPE], 0, type, &retval);
 
   return retval;
 }
