@@ -47,7 +47,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:OBJECT,OBJECT (./eggmarshalers.list:1) */
+/* VOID:OBJECT,OBJECT (../../../lib/egg/eggmarshalers.list:1) */
 void
 _egg_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                   GValue       *return_value,
@@ -84,7 +84,7 @@ _egg_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,STRING,LONG,LONG (./eggmarshalers.list:2) */
+/* VOID:OBJECT,STRING,LONG,LONG (../../../lib/egg/eggmarshalers.list:2) */
 void
 _egg_marshal_VOID__OBJECT_STRING_LONG_LONG (GClosure     *closure,
                                             GValue       *return_value,
@@ -125,7 +125,7 @@ _egg_marshal_VOID__OBJECT_STRING_LONG_LONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,LONG (./eggmarshalers.list:3) */
+/* VOID:OBJECT,LONG (../../../lib/egg/eggmarshalers.list:3) */
 void
 _egg_marshal_VOID__OBJECT_LONG (GClosure     *closure,
                                 GValue       *return_value,
@@ -162,7 +162,7 @@ _egg_marshal_VOID__OBJECT_LONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,STRING,STRING (./eggmarshalers.list:4) */
+/* VOID:OBJECT,STRING,STRING (../../../lib/egg/eggmarshalers.list:4) */
 void
 _egg_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                          GValue       *return_value,
@@ -201,7 +201,7 @@ _egg_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,UINT (./eggmarshalers.list:5) */
+/* VOID:UINT,UINT (../../../lib/egg/eggmarshalers.list:5) */
 void
 _egg_marshal_VOID__UINT_UINT (GClosure     *closure,
                               GValue       *return_value,
@@ -238,7 +238,7 @@ _egg_marshal_VOID__UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* BOOLEAN:INT (./eggmarshalers.list:6) */
+/* BOOLEAN:INT (../../../lib/egg/eggmarshalers.list:6) */
 void
 _egg_marshal_BOOLEAN__INT (GClosure     *closure,
                            GValue       *return_value,
@@ -277,7 +277,7 @@ _egg_marshal_BOOLEAN__INT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:ENUM (./eggmarshalers.list:7) */
+/* BOOLEAN:ENUM (../../../lib/egg/eggmarshalers.list:7) */
 void
 _egg_marshal_BOOLEAN__ENUM (GClosure     *closure,
                             GValue       *return_value,
@@ -316,7 +316,7 @@ _egg_marshal_BOOLEAN__ENUM (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (./eggmarshalers.list:8) */
+/* BOOLEAN:VOID (../../../lib/egg/eggmarshalers.list:8) */
 void
 _egg_marshal_BOOLEAN__VOID (GClosure     *closure,
                             GValue       *return_value,
@@ -353,7 +353,7 @@ _egg_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* OBJECT:VOID (./eggmarshalers.list:9) */
+/* OBJECT:VOID (../../../lib/egg/eggmarshalers.list:9) */
 void
 _egg_marshal_OBJECT__VOID (GClosure     *closure,
                            GValue       *return_value,
@@ -390,9 +390,9 @@ _egg_marshal_OBJECT__VOID (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* VOID:VOID (./eggmarshalers.list:10) */
+/* VOID:VOID (../../../lib/egg/eggmarshalers.list:10) */
 
-/* VOID:INT,INT (./eggmarshalers.list:11) */
+/* VOID:INT,INT (../../../lib/egg/eggmarshalers.list:11) */
 void
 _egg_marshal_VOID__INT_INT (GClosure     *closure,
                             GValue       *return_value,
@@ -429,11 +429,11 @@ _egg_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,UINT (./eggmarshalers.list:12) */
+/* VOID:UINT,UINT (../../../lib/egg/eggmarshalers.list:12) */
 
-/* VOID:BOOLEAN (./eggmarshalers.list:13) */
+/* VOID:BOOLEAN (../../../lib/egg/eggmarshalers.list:13) */
 
-/* VOID:OBJECT,ENUM,BOXED (./eggmarshalers.list:14) */
+/* VOID:OBJECT,ENUM,BOXED (../../../lib/egg/eggmarshalers.list:14) */
 void
 _egg_marshal_VOID__OBJECT_ENUM_BOXED (GClosure     *closure,
                                       GValue       *return_value,
@@ -472,9 +472,9 @@ _egg_marshal_VOID__OBJECT_ENUM_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED (./eggmarshalers.list:15) */
+/* VOID:BOXED (../../../lib/egg/eggmarshalers.list:15) */
 
-/* BOOLEAN:BOOLEAN (./eggmarshalers.list:16) */
+/* BOOLEAN:BOOLEAN (../../../lib/egg/eggmarshalers.list:16) */
 void
 _egg_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                GValue       *return_value,
@@ -513,7 +513,7 @@ _egg_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,STRING,STRING (./eggmarshalers.list:17) */
+/* BOOLEAN:OBJECT,STRING,STRING (../../../lib/egg/eggmarshalers.list:17) */
 void
 _egg_marshal_BOOLEAN__OBJECT_STRING_STRING (GClosure     *closure,
                                             GValue       *return_value,
@@ -556,7 +556,48 @@ _egg_marshal_BOOLEAN__OBJECT_STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* STRING:POINTER (./eggmarshalers.list:18) */
+/* BOOLEAN:ENUM,INT (../../../lib/egg/eggmarshalers.list:18) */
+void
+_egg_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
+                                GValue       *return_value,
+                                guint         n_param_values,
+                                const GValue *param_values,
+                                gpointer      invocation_hint,
+                                gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__ENUM_INT) (gpointer     data1,
+                                                      gint         arg_1,
+                                                      gint         arg_2,
+                                                      gpointer     data2);
+  register GMarshalFunc_BOOLEAN__ENUM_INT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__ENUM_INT) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_enum (param_values + 1),
+                       g_marshal_value_peek_int (param_values + 2),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* STRING:POINTER (../../../lib/egg/eggmarshalers.list:19) */
 void
 _egg_marshal_STRING__POINTER (GClosure     *closure,
                               GValue       *return_value,
@@ -595,7 +636,7 @@ _egg_marshal_STRING__POINTER (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* STRING:STRING,STRING (./eggmarshalers.list:19) */
+/* STRING:STRING,STRING (../../../lib/egg/eggmarshalers.list:20) */
 void
 _egg_marshal_STRING__STRING_STRING (GClosure     *closure,
                                     GValue       *return_value,
