@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-langs.h,v 1.7 2003/10/17 22:40:15 chpe Exp $
+ *  $Id: ephy-langs.h,v 1.9 2004/11/25 13:51:56 chpe Exp $
  */
 
 #ifndef EPHY_LANGS_H
@@ -26,15 +26,28 @@
 
 G_BEGIN_DECLS
 
+#define ISO_639_DOMAIN	"iso_639"
+#define ISO_3166_DOMAIN	"iso_3166"
+
 typedef struct
 {
 	char *title;
 	char *code;
 } EphyFontsLanguageInfo;
 
-const EphyFontsLanguageInfo 	*ephy_font_languages	(void);
+const EphyFontsLanguageInfo *ephy_font_languages	 (void);
 
-guint				 ephy_font_n_languages	(void);
+guint			     ephy_font_n_languages	 (void);
+
+void			     ephy_langs_append_languages (GArray *array);
+
+void			     ephy_langs_sanitise	 (GArray *array);
+
+char			   **ephy_langs_get_languages	 (void);
+
+GHashTable		    *ephy_langs_iso_639_table	 (void);
+
+GHashTable		    *ephy_langs_iso_3166_table   (void);
 
 G_END_DECLS
 
