@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.c,v 1.14 2004/09/13 10:24:56 chpe Exp $
+ *  $Id: ephy-stock-icons.c,v 1.15 2004/11/02 20:57:20 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <gtk/gtk.h>
 #include <glib.h>
