@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.c,v 1.46 2004/08/23 12:42:03 chpe Exp $
+ *  $Id: ephy-node-view.c,v 1.53 2004/11/07 19:32:17 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeviewcolumn.h>
@@ -29,6 +27,7 @@
 #include <gtk/gtkcellrenderertoggle.h>
 #include <gtk/gtktreemodelfilter.h>
 #include <gtk/gtkwindow.h>
+#include <gtk/gtkmain.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "ephy-node-view.h"
@@ -110,9 +109,9 @@ static guint ephy_node_view_signals[LAST_SIGNAL] = { 0 };
 GType
 ephy_node_view_get_type (void)
 {
-	static GType ephy_node_view_type = 0;
+	static GType type = 0;
 
-	if (ephy_node_view_type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -127,12 +126,12 @@ ephy_node_view_get_type (void)
 			(GInstanceInitFunc) ephy_node_view_init
 		};
 
-		ephy_node_view_type = g_type_register_static (GTK_TYPE_TREE_VIEW,
-							      "EphyNodeView",
-							      &our_info, 0);
+		type = g_type_register_static (GTK_TYPE_TREE_VIEW,
+					       "EphyNodeView",
+					       &our_info, 0);
 	}
 
-	return ephy_node_view_type;
+	return type;
 }
 
 static void
@@ -388,7 +387,7 @@ drag_data_received_cb (GtkWidget *widget,
 	if (view->priv->drop_occurred)
 	{
 		EphyNode *node;
-		GList *uris;
+		char **uris;
 		gboolean success = FALSE;
 		GtkTreePath *path;
 
@@ -399,7 +398,7 @@ drag_data_received_cb (GtkWidget *widget,
 
 		node = get_node_from_path (view, path);
 
-		uris = ephy_string_parse_uri_list (selection_data->data);
+		uris = gtk_selection_data_get_uris (selection_data);
 
 		if (uris != NULL)
 		{
@@ -407,8 +406,8 @@ drag_data_received_cb (GtkWidget *widget,
 			g_signal_emit (G_OBJECT (view),
 				       ephy_node_view_signals[NODE_DROPPED], 0,
 				       node, uris);
-			g_list_foreach (uris, (GFunc) g_free, NULL);
-			g_list_free (uris);
+			g_strfreev (uris);
+
 		}
 
 		view->priv->drop_occurred = FALSE;
@@ -1280,13 +1279,8 @@ ephy_node_view_init (EphyNodeView *view)
 {
 	view->priv = EPHY_NODE_VIEW_GET_PRIVATE (view);
 
-	view->priv->remove_if_cancelled = FALSE;
 	view->priv->toggle_column = -1;
-	view->priv->filter = NULL;
-	view->priv->editable_renderer = NULL;
-	view->priv->edited_node = NULL;
 	view->priv->searchable_data_column = -1;
-	view->priv->source_target_list = NULL;
 	view->priv->priority_column = -1;
 	view->priv->priority_prop_id = 0;
 	view->priv->sort_column = -1;
@@ -1577,6 +1571,35 @@ ephy_node_view_add_toggle (EphyNodeView *view, EphyTreeModelNodeValueFunc value_
 	gtk_tree_view_append_column (GTK_TREE_VIEW (view), col);
 }
 
+void
+ephy_node_view_popup (EphyNodeView *view, GtkWidget *menu)
+{
+	GdkEvent *event;
+
+	event = gtk_get_current_event ();
+	if (event)
+	{
+		if (event->type == GDK_KEY_PRESS)
+		{
+			GdkEventKey *key = (GdkEventKey *) event;
+
+			gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
+					ephy_gui_menu_position_tree_selection,
+					view, 0, key->time);
+			gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
+		}
+		else if (event->type == GDK_BUTTON_PRESS)
+		{
+			GdkEventButton *button = (GdkEventButton *) event;
+
+			gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL,
+					NULL, button->button, button->time);
+		}
+
+		gdk_event_free (event);
+	}
+}
+
 static void
 ephy_node_view_class_init (EphyNodeViewClass *klass)
 {
