@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-zoom-control.c,v 1.11 2004/10/23 16:48:51 chpe Exp $
+ *  $Id: ephy-zoom-control.c,v 1.14 2004/11/07 10:01:32 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-zoom-control.h"
 #include "ephy-marshal.h"
@@ -34,7 +32,8 @@
 
 #define EPHY_ZOOM_CONTROL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_ZOOM_CONTROL, EphyZoomControlPrivate))
 
-struct _EphyZoomControlPrivate {
+struct _EphyZoomControlPrivate
+{
 	GtkComboBox *combo;
 	float zoom;
 	guint handler_id;
@@ -121,7 +120,7 @@ ephy_zoom_control_init (EphyZoomControl *control)
 {
 	EphyZoomControlPrivate *p;
 	GtkComboBox *combo;
-	GtkWidget *box;
+	GtkWidget *vbox;
 	guint i;
 
 	p = EPHY_ZOOM_CONTROL_GET_PRIVATE (control);
@@ -129,7 +128,7 @@ ephy_zoom_control_init (EphyZoomControl *control)
 
 	p->zoom = 1.0;
 
-	combo = GTK_COMBO_BOX (gtk_combo_box_new_text ());
+	combo = p->combo = GTK_COMBO_BOX (gtk_combo_box_new_text ());
 
 	for (i = 0; i < n_zoom_levels; i++)
 	{
@@ -144,11 +143,11 @@ ephy_zoom_control_init (EphyZoomControl *control)
 	i = ephy_zoom_get_zoom_level_index (p->zoom);
 	gtk_combo_box_set_active (combo, i);
 
-	box = gtk_vbox_new (TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (combo), TRUE, FALSE, 0);
-	gtk_widget_show (box);
+	vbox = gtk_vbox_new (TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (combo), TRUE, FALSE, 0);
+	gtk_widget_show (vbox);
 
-	gtk_container_add (GTK_CONTAINER (control), box);
+	gtk_container_add (GTK_CONTAINER (control), vbox);
 
 	p->handler_id = g_signal_connect (combo, "changed",
 					  G_CALLBACK (combo_changed_cb), control);
@@ -197,6 +196,30 @@ ephy_zoom_control_get_property (GObject *object,
 	}
 }
 
+static void
+set_combo_tooltip (GtkWidget *widget, 
+		   GtkTooltipsData *data)
+{
+	if (GTK_IS_BUTTON (widget))
+	{
+		gtk_tooltips_set_tip (data->tooltips, widget,
+				      data->tip_text, data->tip_private);
+	}
+}
+
+static void
+combo_realized (GtkWidget *combo,
+		GtkWidget *control)
+{
+	GtkTooltipsData *data;
+
+	data = gtk_tooltips_data_get (control);
+	g_return_if_fail (data != NULL);
+
+	gtk_container_forall (GTK_CONTAINER (combo),
+			      (GtkCallback) set_combo_tooltip, data);
+}
+
 static gboolean
 ephy_zoom_control_set_tooltip (GtkToolItem *tool_item,
 			       GtkTooltips *tooltips,
@@ -204,9 +227,23 @@ ephy_zoom_control_set_tooltip (GtkToolItem *tool_item,
 			       const char *tip_private)
 {
 	EphyZoomControl *control = EPHY_ZOOM_CONTROL (tool_item);
+	GtkWidget *widget = GTK_WIDGET (tool_item);
 
-	gtk_tooltips_set_tip (tooltips, GTK_WIDGET (control->priv->combo),
-			      tip_text, tip_private);
+	/* hack to make tooltips work also on Ctrl-F1 */
+	gtk_tooltips_set_tip (tooltips, widget, tip_text, tip_private);
+
+	g_signal_handlers_disconnect_by_func
+		(control->priv->combo, G_CALLBACK (combo_realized), widget);
+
+	if (GTK_WIDGET_REALIZED (tool_item))
+	{
+		combo_realized (GTK_WIDGET (control->priv->combo), widget);
+	}
+	else
+	{
+		g_signal_connect_after (control->priv->combo, "realize",
+					G_CALLBACK (combo_realized), widget);
+	}
 
 	return TRUE;
 }
