@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-import.c,v 1.37.4.2 2005/02/26 22:30:45 chpe Exp $
+ *  $Id: ephy-bookmarks-import.c,v 1.39 2004/11/02 20:57:33 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <glib.h>
 #include <libxml/HTMLtree.h>
@@ -320,9 +318,9 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 
 			ret = xbel_parse_bookmark (eb, reader, &node);
 
-			keyword = ephy_bookmarks_find_keyword (eb, folder ? folder : "", FALSE);
+			keyword = ephy_bookmarks_find_keyword (eb, folder, FALSE);
 			
-			if (keyword == NULL && folder != NULL && folder[0] != '\0')
+			if (keyword == NULL)
 			{
 				keyword = ephy_bookmarks_add_keyword (eb, folder);
 			}
@@ -339,7 +337,7 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 		{
 			if (type == XML_READER_TYPE_ELEMENT)
 			{
-				ret = xbel_parse_folder (eb, reader, folder ? folder : "");
+				ret = xbel_parse_folder (eb, reader, folder);
 				
 				if (ret != 1) break;
 			}
