@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.87.4.3 2004/11/11 14:19:59 chpe Exp $
+ *  $Id: ephy-bookmarks.c,v 1.93 2004/11/11 14:19:17 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-bookmarks.h"
 #include "ephy-file-helpers.h"
@@ -123,7 +121,7 @@ ephy_bookmarks_get_type (void)
 {
         static GType type = 0;
 
-        if (type == 0)
+        if (G_UNLIKELY (type == 0))
         {
                 static const GTypeInfo our_info =
                 {
@@ -679,12 +677,10 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 	EphyNodeDb *db;
 
 	eb->priv = EPHY_BOOKMARKS_GET_PRIVATE (eb);
-	eb->priv->toolbars_model = NULL;
 
 	db = ephy_node_db_new (EPHY_NODE_DB_BOOKMARKS);
 	eb->priv->db = db;
-	eb->priv->dirty = FALSE;
-	eb->priv->save_timeout_id = 0;
+
 	eb->priv->xml_file = g_build_filename (ephy_dot_dir (),
 					       "ephy-bookmarks.xml",
 					       NULL);
@@ -1180,7 +1176,7 @@ prop_dialog_destroy_cb (EphyBookmarkProperties *dialog,
 	EphyNode *bookmark;
 
 	bookmark = ephy_bookmark_properties_get_node (dialog);
-  	
+
 	g_hash_table_remove (bookmarks->priv->props_dialogs, bookmark);
 }
 
@@ -1203,7 +1199,6 @@ ephy_bookmarks_show_bookmark_properties (EphyBookmarks *bookmarks,
 
 	dialog = g_hash_table_lookup (bookmarks->priv->props_dialogs, bookmark);
 
-	
 	if (dialog == NULL)
 	{
 		dialog = ephy_bookmark_properties_new (bookmarks, bookmark, parent);
