@@ -15,12 +15,17 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-new-bookmark.c,v 1.43.4.2 2004/10/08 12:17:26 marco Exp $
+ *  $Id: ephy-new-bookmark.c,v 1.51 2004/11/10 13:25:51 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
+
+#include "ephy-new-bookmark.h"
+#include "ephy-state.h"
+#include "ephy-topics-selector.h"
+#include "ephy-debug.h"
+#include "ephy-stock-icons.h"
+#include "ephy-gui.h"
 
 #include <gtk/gtktable.h>
 #include <gtk/gtklabel.h>
@@ -31,16 +36,11 @@
 #include <gtk/gtkimage.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtkeditable.h>
+#include <gtk/gtkdialog.h>
+#include <gtk/gtkmessagedialog.h>
 #include <glib/gi18n.h>
 #include <string.h>
 
-#include "ephy-new-bookmark.h"
-#include "ephy-state.h"
-#include "ephy-topics-selector.h"
-#include "ephy-debug.h"
-#include "ephy-stock-icons.h"
-#include "ephy-gui.h"
-
 static void ephy_new_bookmark_class_init (EphyNewBookmarkClass *klass);
 static void ephy_new_bookmark_init (EphyNewBookmark *editor);
 static void ephy_new_bookmark_finalize (GObject *object);
@@ -83,9 +83,9 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_new_bookmark_get_type (void)
 {
-	static GType ephy_new_bookmark_type = 0;
+	static GType type = 0;
 
-	if (ephy_new_bookmark_type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -100,12 +100,12 @@ ephy_new_bookmark_get_type (void)
 			(GInstanceInitFunc) ephy_new_bookmark_init
 		};
 
-		ephy_new_bookmark_type = g_type_register_static (GTK_TYPE_DIALOG,
-							             "EphyNewBookmark",
-							             &our_info, 0);
+		type = g_type_register_static (GTK_TYPE_DIALOG,
+					       "EphyNewBookmark",
+					       &our_info, 0);
 	}
 
-	return ephy_new_bookmark_type;
+	return type;
 }
 
 static void
@@ -263,8 +263,6 @@ build_editing_table (EphyNewBookmark *editor)
 static void
 ephy_new_bookmark_construct (EphyNewBookmark *editor)
 {
-	GdkPixbuf *icon;
-
 	ephy_state_add_window (GTK_WIDGET(editor),
 			       "new_bookmark",
 		               280, 240, FALSE,
@@ -272,12 +270,7 @@ ephy_new_bookmark_construct (EphyNewBookmark *editor)
 
 	gtk_window_set_title (GTK_WINDOW (editor),
 			      _("Add Bookmark"));
-	icon = gtk_widget_render_icon (GTK_WIDGET (editor),
-				       STOCK_ADD_BOOKMARK,
-				       GTK_ICON_SIZE_MENU,
-				       NULL);
-	gtk_window_set_icon (GTK_WINDOW (editor), icon);
-	g_object_unref(icon);
+	gtk_window_set_icon_name (GTK_WINDOW (editor), STOCK_ADD_BOOKMARK);
 
 	gtk_dialog_set_has_separator (GTK_DIALOG (editor), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (editor), 5);
@@ -311,54 +304,23 @@ duplicate_dialog_construct (GtkWindow *parent,
 			    const char *title)
 {
 	GtkWidget *dialog;
-	GtkWidget *hbox, *vbox, *label, *image;
 	char *str, *tmp_str, *tmp_title;
 
-	/* FIXME: We "should" use gtk_message dialog here
-	 * but it doesn't support markup of text yet
-	 * so we build our own. See bug 65501.
-	 */
-
-	dialog = gtk_dialog_new_with_buttons (_("Duplicated Bookmark"),
-					      GTK_WINDOW (parent),
-					      GTK_DIALOG_NO_SEPARATOR,
-					      GTK_STOCK_OK,
-					      GTK_RESPONSE_OK,
-					      NULL);
-	ephy_gui_set_default_window_icon (GTK_WINDOW (dialog));
-
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
-	hbox = gtk_hbox_new (FALSE, 6);
-	gtk_widget_show (hbox);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
-			    TRUE, TRUE, 0);
-
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_INFO,
-					  GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
-
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_widget_show (vbox);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-
-	label = gtk_label_new (NULL);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	tmp_title = g_markup_printf_escaped ("<b>%s</b>", title);
 	tmp_str = g_strdup_printf (_("A bookmark titled %s already exists for this page."),
-			           tmp_title);
+				   tmp_title);
 	str = g_strconcat ("<big>", tmp_str, "</big>", NULL);
-	gtk_label_set_markup (GTK_LABEL (label), str);
+
+	dialog = gtk_message_dialog_new
+		(GTK_WINDOW (parent), GTK_DIALOG_DESTROY_WITH_PARENT,
+		 GTK_MESSAGE_INFO, GTK_BUTTONS_OK, NULL);
+	gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), str);
 	g_free (tmp_title);
 	g_free (tmp_str);
 	g_free (str);
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-	gtk_widget_show (label);
+
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Duplicated Bookmark"));
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 	return dialog;
 }
@@ -473,10 +435,6 @@ static void
 ephy_new_bookmark_init (EphyNewBookmark *editor)
 {
 	editor->priv = EPHY_NEW_BOOKMARK_GET_PRIVATE (editor);
-
-	editor->priv->location = NULL;
-	editor->priv->icon = NULL;
-	editor->priv->id = 0;
 }
 
 void
