@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-automation.c,v 1.21 2004/05/08 20:13:13 chpe Exp $
+ *  $Id: ephy-automation.c,v 1.22 2004/11/02 20:57:20 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-automation.h"
 
