@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-menu.c,v 1.30 2004/10/27 19:54:57 chpe Exp $
+ *  $Id: ephy-encoding-menu.c,v 1.31 2004/11/02 20:57:20 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-encoding-menu.h"
 #include "ephy-encoding-dialog.h"
