@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-favicon-action.h,v 1.6 2004/10/22 17:26:15 chpe Exp $
  */
 
 #ifndef EPHY_FAVICON_ACTION_H
@@ -21,20 +23,22 @@
 
 #include <gtk/gtkaction.h>
 
-#define EPHY_TYPE_FAVICON_ACTION            (ephy_favicon_action_get_type ())
-#define EPHY_FAVICON_ACTION(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), EPHY_TYPE_FAVICON_ACTION, EphyFaviconAction))
-#define EPHY_FAVICON_ACTION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), EPHY_TYPE_FAVICON_ACTION, EphyFaviconActionClass))
-#define EPHY_IS_FAVICON_ACTION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EPHY_TYPE_FAVICON_ACTION))
-#define EPHY_IS_FAVICON_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), EPHY_TYPE_FAVICON_ACTION))
-#define EPHY_FAVICON_ACTION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), EPHY_TYPE_FAVICON_ACTION, EphyFaviconActionClass))
+#define EPHY_TYPE_FAVICON_ACTION		(ephy_favicon_action_get_type ())
+#define EPHY_FAVICON_ACTION(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), EPHY_TYPE_FAVICON_ACTION, EphyFaviconAction))
+#define EPHY_FAVICON_ACTION_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), EPHY_TYPE_FAVICON_ACTION, EphyFaviconActionClass))
+#define EPHY_IS_FAVICON_ACTION(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), EPHY_TYPE_FAVICON_ACTION))
+#define EPHY_IS_FAVICON_ACTION_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((obj), EPHY_TYPE_FAVICON_ACTION))
+#define EPHY_FAVICON_ACTION_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), EPHY_TYPE_FAVICON_ACTION, EphyFaviconActionClass))
 
-typedef struct _EphyFaviconAction      EphyFaviconAction;
-typedef struct _EphyFaviconActionClass EphyFaviconActionClass;
-typedef struct EphyFaviconActionPrivate EphyFaviconActionPrivate;
+typedef struct _EphyFaviconAction		EphyFaviconAction;
+typedef struct _EphyFaviconActionClass		EphyFaviconActionClass;
+typedef struct _EphyFaviconActionPrivate	EphyFaviconActionPrivate;
 
 struct _EphyFaviconAction
 {
 	GtkAction parent;
+
+	/*< private >*/
 	EphyFaviconActionPrivate *priv;
 };
 
