@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright (C) 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.77 2004/10/26 20:02:22 chpe Exp $
+ *  $Id: ephy-history-window.c,v 1.82 2004/11/11 14:17:24 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <gtk/gtktable.h>
 #include <gtk/gtklabel.h>
@@ -66,6 +65,9 @@
 #include "ephy-session.h"
 #include "ephy-favicon-cache.h"
 #include "eel-gconf-extensions.h"
+#include "ephy-node.h"
+#include "ephy-node-common.h"
+#include "ephy-node-view.h"
 
 static GtkTargetEntry page_drag_types [] =
 {
@@ -143,12 +145,14 @@ enum
 
 enum
 {
+	TIME_LAST_HALF_HOUR,
 	TIME_TODAY,
 	TIME_LAST_TWO_DAYS,
 	TIME_LAST_THREE_DAYS,
 	TIME_EVER
 };
 
+#define TIME_LAST_HALF_HOUR_STRING "last_half_hour"
 #define TIME_EVER_STRING "ever"
 #define TIME_TODAY_STRING "today"
 #define TIME_LAST_TWO_DAYS_STRING "last_two_days"
@@ -447,6 +451,23 @@ cmd_delete (GtkAction *action,
 	{
 		ephy_node_view_remove (EPHY_NODE_VIEW (editor->priv->pages_view));
 	}
+	else if (ephy_node_view_is_target (EPHY_NODE_VIEW (editor->priv->sites_view)))
+	{
+		EphyNodePriority priority;
+		GList *selected;
+		EphyNode *node;
+
+		selected = ephy_node_view_get_selection (EPHY_NODE_VIEW (editor->priv->sites_view));
+		node = selected->data;
+		priority = ephy_node_get_property_int (node, EPHY_NODE_KEYWORD_PROP_PRIORITY);
+
+		if (priority == -1) priority = EPHY_NODE_NORMAL_PRIORITY;
+
+		if (priority == EPHY_NODE_NORMAL_PRIORITY)
+		{
+			ephy_node_view_remove (EPHY_NODE_VIEW (editor->priv->sites_view));
+		}
+	}
 }
 
 static void
@@ -823,38 +844,60 @@ add_by_site_filter (EphyHistoryWindow *editor, EphyNodeFilter *filter, int level
 		 level);
 }
 
-#define SEC_PER_DAY (60 * 60 * 24)
-
 static void
-add_by_date_filter (EphyHistoryWindow *editor, EphyNodeFilter *filter, int level,
+add_by_date_filter (EphyHistoryWindow *editor,
+		    EphyNodeFilter *filter,
+		    int level,
 		    EphyNode *equals)
 {
-	GTime now, cmp_time, days;
-	int time_range;
-
-	/* FIXME this is probably wrong for timezones */
+	time_t now, midnight, cmp_time = 0;
+	struct tm btime;
+	int time_range, days = 0;
 
 	time_range = gtk_combo_box_get_active
 		(GTK_COMBO_BOX (editor->priv->time_combo));
 
+	/* no need to setup a new filter */
+	if (time_range == TIME_EVER) return;
+
 	now = time (NULL);
-	days = now / SEC_PER_DAY;
+	if (localtime_r (&now, &btime) == NULL) return;
+
+	/* get start of day */
+	btime.tm_sec = 0;
+	btime.tm_min = 0;
+	btime.tm_hour = 0;
+	midnight = mktime (&btime);
 
 	switch (time_range)
 	{
-		case TIME_EVER:
-			return;
-		case TIME_TODAY:
-			break;
-		case TIME_LAST_TWO_DAYS:
-			days -= 1;
+		case TIME_LAST_HALF_HOUR:
+			cmp_time = now - 30 * 60;
 			break;
 		case TIME_LAST_THREE_DAYS:
-			days -= 2;
+			days++;
+			/* fall-through */
+		case TIME_LAST_TWO_DAYS:
+			days++;
+			/* fall-through */
+		case TIME_TODAY:
+			cmp_time = midnight;
+			break;
+		default:
+			g_return_if_reached ();
 			break;
 	}
 
-	cmp_time = days * SEC_PER_DAY;
+	while (--days >= 0)
+	{
+		/* subtract 1 day */
+		cmp_time -= 43200;
+		localtime_r (&cmp_time, &btime);
+		btime.tm_sec = 0;
+		btime.tm_min = 0;
+		btime.tm_hour = 0;
+		cmp_time = mktime (&btime);
+	}
 
 	ephy_node_filter_add_expression
 		(filter, ephy_node_filter_expression_new
@@ -998,6 +1041,7 @@ build_search_box (EphyHistoryWindow *editor)
 	combo = gtk_combo_box_new_text ();
 	gtk_widget_show (combo);
 
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Last 30 Minutes"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Today"));
 	str = g_strdup_printf (ngettext ("Last %d day", "Last %d days", 2), 2);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), str);
@@ -1011,6 +1055,10 @@ build_search_box (EphyHistoryWindow *editor)
 	g_free (str);
 
 	str = eel_gconf_get_string (CONF_HISTORY_DATE_FILTER);
+	if (str && strcmp (TIME_LAST_HALF_HOUR_STRING, str) == 0)
+	{
+		time_range = TIME_LAST_HALF_HOUR;
+	}
 	if (str && strcmp (TIME_TODAY_STRING, str) == 0)
 	{
 		time_range = TIME_TODAY;
@@ -1231,6 +1279,10 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 			  "node_selected",
 			  G_CALLBACK (site_node_selected_cb),
 			  editor);
+	g_signal_connect (G_OBJECT (sites_view),
+			  "key_press_event",
+			  G_CALLBACK (key_pressed_cb),
+			  editor);
 	g_signal_connect (G_OBJECT (selection),
 			  "changed",
 			  G_CALLBACK (view_selection_changed_cb),
@@ -1405,6 +1457,9 @@ save_date_filter (EphyHistoryWindow *editor)
 
 	switch (time_range)
 	{
+		case TIME_LAST_HALF_HOUR:
+			time_string = TIME_LAST_HALF_HOUR_STRING;
+			break;
 		case TIME_EVER:
 			time_string = TIME_EVER_STRING;
 			break;
