@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-action.c,v 1.29 2004/11/01 14:48:55 chpe Exp $
+ *  $Id: ephy-location-action.c,v 1.30 2004/11/02 20:57:21 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-location-action.h"
 #include "ephy-location-entry.h"
