@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-navigation-action.c,v 1.19 2004/10/23 16:49:10 chpe Exp $
+ *  $Id: ephy-navigation-action.c,v 1.20 2004/11/02 20:57:21 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-navigation-action.h"
 #include "ephy-window.h"
