@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.20.4.4 2004/11/11 17:57:51 chpe Exp $
+ *  $Id: ephy-session.c,v 1.31 2004/11/13 21:39:18 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-session.h"
 
@@ -41,12 +39,13 @@
 #include <errno.h>
 #include <string.h>
 #include <stdlib.h>
-#include <gtk/gtkdialog.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
+#include <gtk/gtkdialog.h>
+#include <gtk/gtkmessagedialog.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libxml/tree.h>
 #include <libxml/xmlwriter.h>
@@ -58,7 +57,7 @@ struct EphySessionPrivate
 	GList *windows;
 	GList *tool_windows;
 	GtkWidget *resume_dialog;
-	gboolean resuming;
+	gboolean dont_save;
 };
 
 #define BOOKMARKS_EDITOR_ID	"BookmarksEditor"
@@ -82,7 +81,7 @@ ephy_session_get_type (void)
 {
 	static GType type = 0;
 
-	if (type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -270,11 +269,6 @@ ephy_session_init (EphySession *session)
 
 	LOG ("EphySession initialising")
 
-	session->priv->windows = NULL;
-	session->priv->tool_windows = NULL;
-	session->priv->resume_dialog = NULL;
-	session->priv->resuming = FALSE;
-
 	ensure_session_directory ();
 }
 
@@ -367,60 +361,30 @@ static gboolean
 offer_to_resume (EphySession *session)
 {
 	GtkWidget *dialog;
-	GtkWidget *label;
-	GtkWidget *vbox;
-	GtkWidget *hbox;
-	GtkWidget *image;
-	char *str;
 	int response;
 
-	dialog = gtk_dialog_new_with_buttons
-		(_("Crash Recovery"), NULL,
-		 GTK_DIALOG_NO_SEPARATOR,
-		 _("_Don't Recover"), GTK_RESPONSE_CANCEL,
-		 _("_Recover"), GTK_RESPONSE_OK,
-		 NULL);
+	dialog = gtk_message_dialog_new
+		(NULL,
+		 GTK_DIALOG_MODAL,
+		 GTK_MESSAGE_WARNING,
+		 GTK_BUTTONS_NONE,
+		 _("Recover previous browser windows and tabs?"));
+
+	gtk_message_dialog_format_secondary_text
+		(GTK_MESSAGE_DIALOG (dialog),
+		 _("Epiphany appears to have exited unexpectedly the last time "
+		   "it was run. You can recover the opened windows and tabs."));
+	
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("_Don't Recover"), GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("_Recover"), GTK_RESPONSE_ACCEPT);
+
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Crash Recovery"));
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+
 	session->priv->resume_dialog = dialog;
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
-
-	hbox = gtk_hbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_BOX (hbox)), 5);
-	gtk_widget_show (hbox);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
-			    TRUE, TRUE, 0);
-
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
-					  GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (hbox), image,
-			    TRUE, TRUE, 0);
-
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_widget_show (vbox);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox,
-			    TRUE, TRUE, 0);
-
-	label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_widget_show (label);
-	str = g_strconcat ("<b>", _("Epiphany appears to have crashed or been killed the last time it was run."),
-			   "</b>", NULL);
-	gtk_label_set_markup (GTK_LABEL (label), str);
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-	g_free (str);
-
-	label = gtk_label_new (_("You can recover the opened tabs and windows."));
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_widget_show (label);
-	gtk_box_pack_start (GTK_BOX (vbox), label,
-			    TRUE, TRUE, 0);
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -428,7 +392,7 @@ offer_to_resume (EphySession *session)
 
 	session->priv->resume_dialog = NULL;
 
-	return (response == GTK_RESPONSE_OK);
+	return (response == GTK_RESPONSE_ACCEPT);
 }
 
 /**
@@ -462,9 +426,9 @@ ephy_session_autoresume (EphySession *session)
 	if (g_file_test (saved_session, G_FILE_TEST_EXISTS)
 	    && offer_to_resume (session))
 	{
-		session->priv->resuming = TRUE;
+		session->priv->dont_save = TRUE;
 		retval = ephy_session_load (session, saved_session);
-		session->priv->resuming = FALSE;
+		session->priv->dont_save = FALSE;
 		ephy_session_save (session, SESSION_CRASHED);
 	}
 
@@ -484,6 +448,7 @@ ephy_session_close (EphySession *session)
 	 * destroying the windows and destroying the tool windows
 	 */
 	g_object_ref (ephy_shell);
+	session->priv->dont_save = TRUE;
 
 	windows	= ephy_session_get_windows (session);
 	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
@@ -493,6 +458,7 @@ ephy_session_close (EphySession *session)
 	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
 	g_list_free (windows);	
 
+	session->priv->dont_save = FALSE;
 	g_object_unref (ephy_shell);
 }
 
@@ -617,7 +583,7 @@ ephy_session_save (EphySession *session,
 	char *save_to, *tmp_file;
 	int ret;
 
-	if (session->priv->resuming)
+	if (session->priv->dont_save)
 	{
 		return TRUE;
 	}
