@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.98 2004/10/27 19:54:57 chpe Exp $
+ *  $Id: ephy-shell.c,v 1.101 2004/11/25 23:03:33 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-shell.h"
 #include "ephy-embed-shell.h"
@@ -241,11 +239,13 @@ save_yourself_cb (GnomeClient *client,
 		  gboolean fast,
 		  EphyShell *shell)
 {
-	char *argv[] = { "epiphany", "--load-session", NULL };
+	char *argv[] = { NULL, "--load-session", NULL };
 	char *discard_argv[] = { "rm", "-f", NULL };
 	EphySession *session;
 	char *tmp, *save_to;
 
+	LOG ("save_yourself_cb")
+
 	tmp = g_build_filename (ephy_dot_dir (),
 				"session_gnome-XXXXXX",
 				NULL);
@@ -254,6 +254,7 @@ save_yourself_cb (GnomeClient *client,
 
 	session = EPHY_SESSION (ephy_shell_get_session (shell));
 
+	argv[0] = g_get_prgname ();
 	argv[2] = save_to;
 	gnome_client_set_restart_command
 		(client, 3, argv);
@@ -275,6 +276,8 @@ die_cb (GnomeClient* client,
 {
 	EphySession *session;
 
+	LOG ("die_cb")
+
 	session = EPHY_SESSION (ephy_shell_get_session (shell));
 	ephy_session_close (session);
 }
@@ -564,7 +567,7 @@ ephy_shell_new_tab (EphyShell *shell,
 	embed = ephy_tab_get_embed (tab);
 
 	ephy_window_add_tab (window, tab, position, jump_to);
-	gtk_window_present (GTK_WINDOW (window));
+	gtk_widget_show (GTK_WIDGET (window));
 
 	if (flags & EPHY_NEW_TAB_HOME_PAGE ||
 	    flags & EPHY_NEW_TAB_NEW_PAGE)
