@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.c,v 1.6 2004/05/20 22:43:09 chpe Exp $
+ *  $Id: ephy-statusbar.c,v 1.13 2004/11/10 16:53:28 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-statusbar.h"
 #include "ephy-stock-icons.h"
@@ -50,6 +48,8 @@ struct EphyStatusbarPrivate
 	GtkWidget *security_icon;
 	GtkWidget *progressbar;
 	GtkWidget *security_evbox;
+	GtkWidget *popups_manager_icon;
+	GtkWidget *popups_manager_evbox;
 };
 
 GType
@@ -57,7 +57,7 @@ ephy_statusbar_get_type (void)
 {
 	static GType type = 0;
 
-	if (type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -117,6 +117,36 @@ create_statusbar_security_icon (EphyStatusbar *s)
 			    FALSE, TRUE, 0);
 }
 
+static void
+create_statusbar_popups_manager_icon (EphyStatusbar *s)
+{
+	s->popups_manager_frame = gtk_frame_new (NULL);
+	gtk_frame_set_shadow_type (GTK_FRAME (s->popups_manager_frame),
+				   GTK_SHADOW_IN);
+
+	s->priv->popups_manager_icon = gtk_image_new_from_stock
+		(EPHY_STOCK_POPUPS, GTK_ICON_SIZE_MENU);
+
+	s->priv->popups_manager_evbox = gtk_event_box_new ();
+
+	gtk_event_box_set_visible_window
+		(GTK_EVENT_BOX (s->priv->popups_manager_evbox), FALSE);
+
+	gtk_container_add (GTK_CONTAINER (s->popups_manager_frame),
+			   GTK_WIDGET (s->priv->popups_manager_evbox));
+	gtk_container_add (GTK_CONTAINER (s->priv->popups_manager_evbox),
+			   GTK_WIDGET (s->priv->popups_manager_icon));
+
+	gtk_widget_show (s->priv->popups_manager_evbox);
+	gtk_widget_show (s->priv->popups_manager_icon);
+
+	/* note lack of gtk_widget_show (s->popups_manager_frame); */
+
+	gtk_box_pack_start (GTK_BOX (s->priv->icon_container),
+			    GTK_WIDGET (s->popups_manager_frame),
+			    FALSE, TRUE, 0);
+}
+
 static void
 create_statusbar_progress (EphyStatusbar *s)
 {
@@ -130,7 +160,7 @@ create_statusbar_progress (EphyStatusbar *s)
 
 static void
 sync_shadow_type (EphyStatusbar *statusbar,
-		  GParamSpec *pspec,
+		  GtkStyle *previous_style,
 		  gpointer dummy)
 {
 	GtkShadowType shadow;
@@ -165,16 +195,14 @@ ephy_statusbar_init (EphyStatusbar *t)
 	gtk_box_reorder_child (GTK_BOX (t), t->priv->icon_container, 0);
 	gtk_widget_show (t->priv->icon_container);
 
-	/* FIXME: enable this when gtk+ bug 73359 is fixed */
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (t), FALSE);
+	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (t), TRUE);
 
 	create_statusbar_progress (t);
 	create_statusbar_security_icon (t);
+	create_statusbar_popups_manager_icon (t);
 
-	/* FIXME: is this the right way ? */
 	sync_shadow_type (t, NULL, NULL);
-	g_signal_connect (t, "notify::shadow-type",
-			  G_CALLBACK (sync_shadow_type), NULL);
+	g_signal_connect (t, "style-set", G_CALLBACK (sync_shadow_type), NULL);
 }
 
 static void
@@ -202,28 +230,51 @@ ephy_statusbar_new (void)
 
 /**
  * ephy_statusbar_set_security_state:
- * @statusbar: a #EphyStatusbar
- * @secure: whether to set the icon to show secure or insecure
+ * @statusbar: an #EphyStatusbar
+ * @stock_id: stock-id of the icon showing the security state
  * @tooltip: a string detailing the security state
  * 
  * Sets the statusbar's security icon and its tooltip.
  **/
 void
 ephy_statusbar_set_security_state (EphyStatusbar *statusbar,
-				   gboolean secure,
+				   const char *stock_id,
 				   const char *tooltip)
 {
-	const char *stock;
-
-	stock = secure ? EPHY_STOCK_SECURE : EPHY_STOCK_UNSECURE;
-
-	gtk_image_set_from_stock (GTK_IMAGE (statusbar->priv->security_icon), stock,
-				  GTK_ICON_SIZE_MENU);
+	gtk_image_set_from_stock (GTK_IMAGE (statusbar->priv->security_icon),
+				  stock_id, GTK_ICON_SIZE_MENU);
 
 	gtk_tooltips_set_tip (statusbar->tooltips, statusbar->priv->security_evbox,
 			      tooltip, NULL);
 }
 
+/**
+ * ephy_statusbar_set_popups_state:
+ * @statusbar: an #EphyStatusbar
+ * @hidden: %TRUE if popups have been hidden
+ * @tooltip: a string to display as tooltip, or %NULL
+ *
+ * Sets the statusbar's popup-blocker icon's tooltip and visibility.
+ **/
+void
+ephy_statusbar_set_popups_state (EphyStatusbar *statusbar,
+				 gboolean hidden,
+				 const char *tooltip)
+{
+	if (hidden)
+	{
+		gtk_widget_hide (statusbar->popups_manager_frame);
+	}
+	else
+	{
+		gtk_tooltips_set_tip (statusbar->tooltips,
+				      statusbar->priv->popups_manager_evbox,
+				      tooltip, NULL);
+
+		gtk_widget_show (statusbar->popups_manager_frame);
+	}
+}
+
 /**
  * ephy_statusbar_set_progress:
  * @statusbar: a #EphyStatusbar
