@@ -18,12 +18,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.c,v 1.117 2004/10/27 19:54:57 chpe Exp $
+ *  $Id: ephy-tab.c,v 1.120 2004/11/21 13:56:32 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-tab.h"
 #include "eel-gconf-extensions.h"
@@ -262,14 +260,18 @@ ephy_tab_size_allocate (GtkWidget *widget,
 			GtkAllocation *allocation)
 {
 	GtkWidget *child;
+	GtkAllocation invalid = { -1, -1, 1, 1 };
 
 	widget->allocation = *allocation;
 
 	child = GTK_BIN (widget)->child;
 	g_return_if_fail (child != NULL);
 
-	/* only resize if we're mapped (which means we're drawable) */
-	if (GTK_WIDGET_MAPPED (child))
+	/* only resize if we're mapped (bug #128191),
+	 * or if this is the initial size-allocate (bug #156854).
+	 */
+	if (GTK_WIDGET_MAPPED (child) ||
+	    memcmp (&child->allocation, &invalid, sizeof (GtkAllocation)) == 0)
 	{
 		gtk_widget_size_allocate (child, allocation);
 	}
@@ -287,8 +289,13 @@ ephy_tab_map (GtkWidget *widget)
 
 	/* we do this since the window might have been resized while this
 	 * tab wasn't mapped (i.e. was a non-active tab during the resize).
+	 * See bug #156854.
 	 */
-	gtk_widget_size_allocate (child, &widget->allocation);
+	if (memcmp (&widget->allocation, &child->allocation,
+	    sizeof (GtkAllocation)) != 0)
+	{
+		gtk_widget_size_allocate (child, &widget->allocation);
+	}
 
 	GTK_WIDGET_CLASS (parent_class)->map (widget);	
 }
@@ -1112,85 +1119,70 @@ build_load_percent (int requests_done, int requests_total)
 	return percent;
 }
 
-static char *
-get_host_name_from_uri (const char *uri)
+static void
+update_net_state_message (EphyTab *tab, const char *uri, EmbedState flags)
 {
 	GnomeVFSURI *vfs_uri = NULL;
+	const char *msg = NULL;
 	const char *host = NULL;
-	char *result;
 
-	if (uri)
+	if (uri != NULL)
 	{
 		vfs_uri = gnome_vfs_uri_new (uri);
 	}
 
-	if (vfs_uri)
+	if (vfs_uri != NULL)
 	{
 		host = gnome_vfs_uri_get_host_name (vfs_uri);
 	}
 
-	if (!host)
-	{
-		host = _("site");
-	}
-
-	result = g_strdup (host);
-
-	if (vfs_uri) gnome_vfs_uri_unref (vfs_uri);
-
-	return result;
-}
-
-static void
-update_net_state_message (EphyTab *tab, const char *uri, EmbedState flags)
-{
-	const char *msg = NULL;
-	char *host;
-
-	host = get_host_name_from_uri (uri);
+	if (host == NULL || host[0] == '\0') goto out;
 
 	/* IS_REQUEST and IS_NETWORK can be both set */
-
 	if (flags & EMBED_STATE_IS_REQUEST)
-        {
-                if (flags & EMBED_STATE_REDIRECTING)
-                {
+	{
+		if (flags & EMBED_STATE_REDIRECTING)
+		{
 			msg = _("Redirecting to %s...");
-                }
-                else if (flags & EMBED_STATE_TRANSFERRING)
-                {
+		}
+		else if (flags & EMBED_STATE_TRANSFERRING)
+		{
 			msg = _("Transferring data from %s...");
-                }
-                else if (flags & EMBED_STATE_NEGOTIATING)
-                {
+		}
+		else if (flags & EMBED_STATE_NEGOTIATING)
+		{
 			msg = _("Waiting for authorization from %s...");
-                }
-        }
+		}
+	}
 
 	if (flags & EMBED_STATE_IS_NETWORK)
-        {
-                if (flags & EMBED_STATE_START)
-                {
-                        msg = _("Loading %s...");
-                }
-        }
+	{
+		if (flags & EMBED_STATE_START)
+		{
+			msg = _("Loading %s...");
+		}
+	}
 
 	if ((flags & EMBED_STATE_IS_NETWORK) &&
 	    (flags & EMBED_STATE_STOP))
-        {
+	{
 		g_free (tab->priv->status_message);
 		tab->priv->status_message = NULL;
 		g_object_notify (G_OBJECT (tab), "message");
 
 	}
-	else if (msg)
+	else if (msg != NULL)
 	{
 		g_free (tab->priv->status_message);
 		tab->priv->status_message = g_strdup_printf (msg, host);
 		g_object_notify (G_OBJECT (tab), "message");
 	}
 
-	g_free (host);
+out:
+	if (vfs_uri != NULL)
+	{
+		gnome_vfs_uri_unref (vfs_uri);
+	}
 }
 
 static void
