@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.h,v 1.14 2004/01/01 22:57:16 chpe Exp $
+ *  $Id: ephy-tab.h,v 1.18 2004/10/08 21:11:17 chpe Exp $
  */
 
 #ifndef EPHY_TAB_H
@@ -24,8 +24,7 @@
 
 #include "ephy-embed.h"
 
-#include <glib-object.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtkbin.h>
 
 G_BEGIN_DECLS
 
@@ -36,9 +35,9 @@ G_BEGIN_DECLS
 #define EPHY_IS_TAB_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_TAB))
 #define EPHY_TAB_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_TAB, EphyTabClass))
 
-typedef struct EphyTabClass	EphyTabClass;
-typedef struct EphyTab		EphyTab;
-typedef struct EphyTabPrivate	EphyTabPrivate;
+typedef struct _EphyTabClass	EphyTabClass;
+typedef struct _EphyTab		EphyTab;
+typedef struct _EphyTabPrivate	EphyTabPrivate;
 
 typedef enum
 {
@@ -54,22 +53,19 @@ typedef enum
 	TAB_ADDRESS_EXPIRE_CURRENT
 } TabAddressExpire;
 
-struct EphyTab
+struct _EphyTab
 {
-	GObject parent;
+	GtkBin parent;
 
 	/*< private >*/
 	EphyTabPrivate *priv;
 };
 
-struct EphyTabClass
+struct _EphyTabClass
 {
-	GObjectClass parent_class;
+	GtkBinClass parent_class;
 };
 
-/* Include the header down here to resolve circular dependency */
-#include "ephy-window.h"
-
 GType			ephy_tab_get_type		(void);
 
 EphyTab	               *ephy_tab_new			(void);
@@ -80,11 +76,6 @@ EphyEmbed              *ephy_tab_get_embed		(EphyTab *tab);
 
 EphyTab		       *ephy_tab_for_embed		(EphyEmbed *embed);
 
-void			ephy_tab_set_window		(EphyTab *tab,
-							 EphyWindow *window);
-
-EphyWindow             *ephy_tab_get_window		(EphyTab *tab);
-
 const char             *ephy_tab_get_icon_address	(EphyTab *tab);
 
 gboolean		ephy_tab_get_load_status	(EphyTab *tab);
@@ -112,9 +103,6 @@ const char             *ephy_tab_get_status_message	(EphyTab *tab);
 
 const char             *ephy_tab_get_title		(EphyTab *tab);
 
-void			ephy_tab_set_visibility		(EphyTab *tab,
-							 gboolean visible);
-
 gboolean		ephy_tab_get_visibility		(EphyTab *tab);
 
 float			ephy_tab_get_zoom		(EphyTab *tab);
