@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.206.4.17 2004/12/18 21:03:37 chpe Exp $
+ *  $Id: ephy-window.c,v 1.235 2004/11/27 21:44:33 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-window.h"
 #include "ephy-command-manager.h"
@@ -88,6 +86,7 @@ static void ephy_window_view_popup_windows_cb	(GtkAction *action,
 static GtkActionEntry ephy_menu_entries [] = {
 
 	/* Toplevel */
+
 	{ "File", NULL, N_("_File") },
 	{ "Edit", NULL, N_("_Edit") },
 	{ "View", NULL, N_("_View") },
@@ -99,6 +98,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "PopupAction", NULL, "" },
 
 	/* File menu */
+
 	{ "FileNewWindow", GTK_STOCK_NEW, N_("_New Window"), "<control>N",
 	  N_("Open a new window"),
 	  G_CALLBACK (window_cmd_file_new_window) },
@@ -123,7 +123,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "FilePrint", GTK_STOCK_PRINT, N_("_Print..."), "<control>P",
 	  N_("Print the current page"),
 	  G_CALLBACK (window_cmd_file_print) },
-	{ "FileSendTo", STOCK_SEND_MAIL, N_("S_end To..."), NULL,
+	{ "FileSendTo", STOCK_SEND_MAIL, N_("S_end To..."), "<control>M",
 	  N_("Send a link of the current page"),
 	  G_CALLBACK (window_cmd_file_send_to) },
 	{ "FileCloseWindow", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
@@ -131,6 +131,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_file_close_window) },
 
 	/* Edit menu */
+
 	{ "EditUndo", GTK_STOCK_UNDO, N_("_Undo"), "<control>Z",
 	  N_("Undo the last action"),
 	  G_CALLBACK (window_cmd_edit_undo) },
@@ -169,6 +170,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_edit_prefs) },
 
 	/* View menu */
+
 	{ "ViewStop", GTK_STOCK_STOP, N_("_Stop"), "Escape",
 	  N_("Stop current data transfer"),
 	  G_CALLBACK (window_cmd_view_stop) },
@@ -192,6 +194,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_view_page_source) },
 
 	/* Bookmarks menu */
+
 	{ "FileBookmarkPage", STOCK_ADD_BOOKMARK, N_("_Add Bookmark..."), "<control>D",
 	  N_("Add a bookmark for the current page"),
 	  G_CALLBACK (window_cmd_file_bookmark_page) },
@@ -200,6 +203,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_go_bookmarks) },
 
 	/* Go menu */
+
 	{ "GoBack", GTK_STOCK_GO_BACK, N_("_Back"), "<alt>Left",
 	  N_("Go to the previous visited page"),
 	  G_CALLBACK (window_cmd_go_back) },
@@ -220,6 +224,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_go_history) },
 
 	/* Tabs menu */
+
 	{ "TabsPrevious", NULL, N_("_Previous Tab"), "<control>Page_Up",
 	  N_("Activate previous tab"),
 	  G_CALLBACK (window_cmd_tabs_previous) },
@@ -237,6 +242,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	  G_CALLBACK (window_cmd_tabs_detach) },
 
 	/* Help menu */
+
 	{"HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
 	 N_("Display web browser help"),
 	 G_CALLBACK (window_cmd_help_contents) },
@@ -249,11 +255,13 @@ static guint ephy_menu_n_entries = G_N_ELEMENTS (ephy_menu_entries);
 static GtkToggleActionEntry ephy_menu_toggle_entries [] =
 {
 	/* File Menu */
+
 	{ "FileWorkOffline", NULL, N_("_Work Offline"), NULL,
 	  N_("Toggle network status"),
 	  G_CALLBACK (window_cmd_file_work_offline), FALSE },
 
 	/* View Menu */
+
 	{ "ViewToolbar", NULL, N_("_Toolbar"), "<shift><control>T",
 	  N_("Show or hide toolbar"),
 	  G_CALLBACK (ephy_window_view_toolbar_cb), TRUE },
@@ -277,6 +285,7 @@ static guint ephy_menu_n_toggle_entries = G_N_ELEMENTS (ephy_menu_toggle_entries
 
 static GtkActionEntry ephy_popups_entries [] = {
 	/* Document */
+
 	{ "SaveBackgroundAs", NULL, N_("_Save Background As..."), NULL,
 	  NULL, G_CALLBACK (popup_cmd_save_background_as) },
 	{ "ContextBookmarkPage", STOCK_ADD_BOOKMARK, N_("Add Boo_kmark..."), "<control>D",
@@ -284,26 +293,42 @@ static GtkActionEntry ephy_popups_entries [] = {
 	  G_CALLBACK (window_cmd_file_bookmark_page) },
 
 	/* Framed document */
+
 	{ "OpenFrame", NULL, N_("_Open Frame"), NULL,
-	  NULL, G_CALLBACK (popup_cmd_open_frame) },
+	  N_("Open frame in this window"),
+	  G_CALLBACK (popup_cmd_open_frame) },
 
 	/* Links */
-	{ "OpenLink", GTK_STOCK_OPEN, N_("_Open Link"),
-	  NULL, NULL, G_CALLBACK (popup_cmd_open_link) },
+
+	{ "OpenLink", GTK_STOCK_OPEN, N_("_Open Link"), NULL,
+	  N_("Open link in this window"),
+	  G_CALLBACK (popup_cmd_open_link) },
 	{ "OpenLinkInNewWindow", NULL, N_("Open Link in _New Window"), NULL,
-	  NULL, G_CALLBACK (popup_cmd_link_in_new_window) },
-	{ "OpenLinkInNewTab", NULL, N_("Open Link in New _Tab"),
-	  NULL, NULL, G_CALLBACK (popup_cmd_link_in_new_tab) },
+	  N_("Open link in a new window"),
+	  G_CALLBACK (popup_cmd_link_in_new_window) },
+	{ "OpenLinkInNewTab", NULL, N_("Open Link in New _Tab"), NULL,
+	  N_("Open link in a new tab"),
+	  G_CALLBACK (popup_cmd_link_in_new_tab) },
 	{ "DownloadLink", EPHY_STOCK_DOWNLOAD, N_("_Download Link"), NULL,
 	  NULL, G_CALLBACK (popup_cmd_download_link) },
 	{ "DownloadLinkAs", GTK_STOCK_SAVE_AS, N_("_Save Link As..."), NULL,
-	  NULL, G_CALLBACK (popup_cmd_download_link_as) },
+	  N_("Save link with a different name"),
+	  G_CALLBACK (popup_cmd_download_link_as) },
 	{ "BookmarkLink", STOCK_ADD_BOOKMARK, N_("_Bookmark Link..."),
 	  NULL, NULL, G_CALLBACK (popup_cmd_bookmark_link) },
 	{ "CopyLinkAddress", NULL, N_("_Copy Link Address"), NULL,
 	  NULL, G_CALLBACK (popup_cmd_copy_link_address) },
 
+	/* Email links */
+
+	/* This is on the context menu on a mailto: link and opens the mail program */
+	{ "SendEmail", GTK_STOCK_OPEN, N_("_Send Email..."),
+	  NULL, NULL, G_CALLBACK (popup_cmd_open_link) },
+	{ "CopyEmailAddress", NULL, N_("_Copy Email Address"), NULL,
+	  NULL, G_CALLBACK (popup_cmd_copy_link_address) },
+
 	/* Images */
+
 	{ "OpenImage", GTK_STOCK_OPEN, N_("Open _Image"), NULL,
 	  NULL, G_CALLBACK (popup_cmd_open_image) },
 	{ "SaveImageAs", GTK_STOCK_SAVE_AS, N_("_Save Image As..."), NULL,
@@ -319,6 +344,8 @@ static guint ephy_popups_n_entries = G_N_ELEMENTS (ephy_popups_entries);
 #define CONF_DESKTOP_BG_PICTURE "/desktop/gnome/background/picture_filename"
 #define INSANE_NUMBER_OF_URLS 20
 
+#define BOOKMARKS_MENU_PATH "/menubar/BookmarksMenu"
+
 #define EPHY_WINDOW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_WINDOW, EphyWindowPrivate))
 
 struct _EphyWindowPrivate
@@ -329,6 +356,7 @@ struct _EphyWindowPrivate
 	Toolbar *toolbar;
 	GtkWidget *bookmarksbar;
 	GtkWidget *statusbar;
+	GtkUIManager *manager;
 	GtkActionGroup *action_group;
 	GtkActionGroup *popups_action_group;
 	EphyFavoritesMenu *fav_menu;
@@ -366,7 +394,8 @@ enum
 {
 	PROP_0,
 	PROP_ACTIVE_TAB,
-	PROP_CHROME
+	PROP_CHROME,
+	PROP_PPV_MODE
 };
 
 static GObjectClass *parent_class = NULL;
@@ -376,7 +405,7 @@ ephy_window_get_type (void)
 {
         static GType type = 0;
 
-        if (type == 0)
+        if (G_UNLIKELY (type == 0))
         {
                 static const GTypeInfo our_info =
                 {
@@ -400,15 +429,16 @@ ephy_window_get_type (void)
 }
 
 static void
-update_exit_fullscreen_popup_position (EphyWindow *window)
+update_fullscreen_popup (EphyWindow *window)
 {
 	GtkWidget *popup = window->priv->exit_fullscreen_popup;
-	GdkRectangle screen_rect;
 	int popup_width, popup_height;
+	GdkRectangle screen_rect;
 
 	g_return_if_fail (popup != NULL);
 
-	gtk_window_get_size (GTK_WINDOW (popup), &popup_width, &popup_height);
+	popup_width = popup->requisition.width;
+	popup_height = popup->requisition.height;
 
 	/* FIXME multihead */
 	gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
@@ -434,7 +464,7 @@ static void
 screen_size_changed_cb (GdkScreen *screen,
 			EphyWindow *window)
 {
-	update_exit_fullscreen_popup_position (window);
+	update_fullscreen_popup (window);
 }
 
 static void
@@ -456,7 +486,6 @@ static void
 ephy_window_destroy (GtkObject *gtkobject)
 {
 	EphyWindow *window = EPHY_WINDOW (gtkobject);
-	GSList *popups;
 
 	LOG ("EphyWindow destroy %p", window)
 
@@ -473,15 +502,13 @@ ephy_window_destroy (GtkObject *gtkobject)
 
 	destroy_exit_fullscreen_popup (window);
 
-	popups = gtk_ui_manager_get_toplevels (GTK_UI_MANAGER (window->ui_merge), GTK_UI_MANAGER_POPUP);
-	g_slist_foreach (popups, (GFunc) gtk_menu_shell_deactivate, NULL);
-	g_slist_free (popups);
-
         GTK_OBJECT_CLASS (parent_class)->destroy (gtkobject);
 }
 
 static void
-add_widget (GtkUIManager *merge, GtkWidget *widget, EphyWindow *window)
+add_widget (GtkUIManager *manager,
+	    GtkWidget *widget,
+	    EphyWindow *window)
 {
 	gtk_box_pack_start (GTK_BOX (window->priv->menu_dock),
 			    widget, FALSE, FALSE, 0);
@@ -533,8 +560,7 @@ sync_chromes_visibility (EphyWindow *window)
 				&show_statusbar, &show_toolbar,
 				&show_bookmarksbar);
 
-	menubar = gtk_ui_manager_get_widget
-		(GTK_UI_MANAGER (window->ui_merge), "/menubar");
+	menubar = gtk_ui_manager_get_widget (window->priv->manager, "/menubar");
 	g_assert (menubar != NULL);
 
 	g_object_set (G_OBJECT (menubar), "visible", show_menubar, NULL);
@@ -543,6 +569,12 @@ sync_chromes_visibility (EphyWindow *window)
 	g_object_set (G_OBJECT (window->priv->statusbar), "visible", show_statusbar, NULL);
 }
 
+static void
+fullscreen_popup_size_request_cb (GtkWidget *popup, GtkRequisition *req, EphyWindow *window)
+{
+	update_fullscreen_popup (window);
+}
+
 static void
 ephy_window_fullscreen (EphyWindow *window)
 {
@@ -585,8 +617,10 @@ ephy_window_fullscreen (EphyWindow *window)
 	/* FIXME multihead */
 	g_signal_connect (gdk_screen_get_default (), "size-changed",
 			  G_CALLBACK (screen_size_changed_cb), window);
+	g_signal_connect (popup, "size_request",
+			  G_CALLBACK (fullscreen_popup_size_request_cb), window);
 
-	update_exit_fullscreen_popup_position (window);
+	update_fullscreen_popup (window);
 
 	gtk_widget_show (popup);
 
@@ -651,57 +685,44 @@ static gboolean
 confirm_close_with_modified_forms (EphyWindow *window)
 {
 	GtkWidget *dialog;
-	GtkWidget *hbox, *vbox, *label, *image;
-	char *text;
+	GtkWindowGroup *group;
 	int response;
 
-	dialog = gtk_dialog_new_with_buttons ("",
-					      GTK_WINDOW (window),
-					      GTK_DIALOG_NO_SEPARATOR | GTK_DIALOG_MODAL,
-					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					      _("Close _Document"), GTK_RESPONSE_OK,
-					      NULL);
+	dialog = gtk_message_dialog_new
+		(GTK_WINDOW (window),
+		 GTK_DIALOG_MODAL,
+		 GTK_MESSAGE_WARNING,
+		 GTK_BUTTONS_CANCEL,
+		 _("There are unsubmitted changes to form elements."));
 
-	ephy_gui_set_default_window_icon (GTK_WINDOW (dialog));
+	gtk_message_dialog_format_secondary_text
+		(GTK_MESSAGE_DIALOG (dialog),
+		 _("If you close the document anyway, "
+		   "you will lose that information."));
 	
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("Close _Document"), GTK_RESPONSE_ACCEPT);
 
-	hbox = gtk_hbox_new (FALSE, 6);
-	gtk_widget_show (hbox);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
-			    TRUE, TRUE, 0);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
-					  GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
+	/* FIXME set title */
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_widget_show (vbox);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
+	group = GTK_WINDOW (window)->group;
+	if (group == NULL)
+	{
+		group = gtk_window_group_new ();
+		gtk_window_group_add_window (group, GTK_WINDOW (window));
+		g_object_unref (group);
+	}
 
-	label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-
-	text = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
-				_("There are unsubmitted changes to form elements."),
-				_("If you close the document anyway, you will lose that information."));
-	gtk_label_set_markup (GTK_LABEL (label), text);
-	g_free (text);
-
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-	gtk_widget_show (label);
+	gtk_window_group_add_window (group, GTK_WINDOW (dialog));
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
 	gtk_widget_destroy (dialog);
 
-	return response == GTK_RESPONSE_OK;
+	return response == GTK_RESPONSE_ACCEPT;
 }
 
 static void
@@ -722,17 +743,32 @@ ephy_window_key_press_event (GtkWidget *widget,
 {
 	EphyWindow *window = EPHY_WINDOW (widget);
 	GtkWidget *menubar;
-	guint modifiers = gtk_accelerator_get_default_mod_mask ();
+	guint keyval = GDK_F10;
+	guint modifier = 0;
+	guint mask = gtk_accelerator_get_default_mod_mask ();
+	char *accel = NULL;
 
-	/* Show and activate the menubar on F10, if it isn't visible,
-	 * unless we're in ppv mode
-	 */
-        if (window->priv->ppv_mode == FALSE &&
-	    event->keyval == GDK_F10 &&
-	    (event->state & modifiers) == 0)
+	/* Don't activate menubar in ppv mode */
+	if (window->priv->ppv_mode)
 	{
-		menubar = gtk_ui_manager_get_widget
-			(GTK_UI_MANAGER (window->ui_merge), "/menubar");
+		return FALSE;
+	}
+
+	g_object_get (gtk_widget_get_settings (widget),
+		      "gtk-menu-bar-accel", &accel,
+		      NULL);
+
+	if (accel != NULL)
+	{
+		gtk_accelerator_parse (accel, &keyval, &modifier);
+
+		g_free (accel);
+	}
+
+	/* Show and activate the menubar, if it isn't visible */
+        if (event->keyval == keyval && (event->state & mask) == (modifier & mask))
+	{
+		menubar = gtk_ui_manager_get_widget (window->priv->manager, "/menubar");
 		g_return_val_if_fail (menubar != NULL , FALSE);
 	
 		if (!GTK_WIDGET_VISIBLE (menubar))
@@ -903,7 +939,7 @@ init_menu_updaters (EphyWindow *window)
 	GtkWidget *edit_menu_item, *edit_menu;
 
 	edit_menu_item = gtk_ui_manager_get_widget
-		(GTK_UI_MANAGER (window->ui_merge), "/menubar/EditMenu");
+		(window->priv->manager, "/menubar/EditMenu");
 	edit_menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (edit_menu_item));
 
 	g_signal_connect (edit_menu, "show",
@@ -1008,34 +1044,14 @@ update_chromes_actions (EphyWindow *window)
 		 			   window);
 }
 
-static void
-update_print_actions (EphyWindow *window,
-		      gboolean enable)
-{
-	GtkActionGroup *action_group = window->priv->action_group;
-	GtkAction *action;
-	gboolean printing, print_setup;
-
-	printing = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINTING);
-	print_setup = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINT_SETUP) &&
-		!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_COMMAND_LINE);
-
-	action = gtk_action_group_get_action (action_group, "FilePrintSetup");
-	g_object_set (action, "sensitive", printing && print_setup, NULL);
-	action = gtk_action_group_get_action (action_group, "FilePrintPreview");
-	g_object_set (action, "sensitive", enable && printing && print_setup, NULL);
-	action = gtk_action_group_get_action (action_group, "FilePrint");
-	g_object_set (action, "sensitive", enable && printing, NULL);
-
-}
-
 static void
 update_actions_sensitivity (EphyWindow *window)
 {
 	GtkActionGroup *action_group = window->priv->action_group;
 	GtkActionGroup *popups_action_group = window->priv->popups_action_group;
 	GtkAction *action;
-	gboolean bookmarks_editable, save_to_disk, fullscreen;
+	gboolean bookmarks_editable, save_to_disk;
+	gboolean printing, print_setup, fullscreen;
 
 	action = gtk_action_group_get_action (action_group, "ViewToolbar");
 	g_object_set (action, "sensitive", eel_gconf_key_is_writable (CONF_WINDOWS_SHOW_TOOLBARS), NULL);
@@ -1073,6 +1089,17 @@ update_actions_sensitivity (EphyWindow *window)
 	g_object_set (action, "sensitive", save_to_disk, NULL);
 	action = gtk_action_group_get_action (popups_action_group, "SaveImageAs");
 	g_object_set (action, "sensitive", save_to_disk, NULL);
+
+	printing = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINTING);
+	print_setup = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINT_SETUP) &&
+		!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_COMMAND_LINE);
+	action = gtk_action_group_get_action (action_group, "FilePrintSetup");
+	g_object_set (action, "sensitive", printing && print_setup, NULL);
+	action = gtk_action_group_get_action (action_group, "FilePrintPreview");
+	g_object_set (action, "sensitive", printing && print_setup, NULL);
+	action = gtk_action_group_get_action (action_group, "FilePrint");
+	g_object_set (action, "sensitive", printing, NULL);
+
 	action = gtk_action_group_get_action (popups_action_group, "SetImageAsBackground");
 	g_object_set (action, "sensitive", eel_gconf_key_is_writable (CONF_DESKTOP_BG_PICTURE), NULL);
 
@@ -1086,8 +1113,6 @@ update_actions_sensitivity (EphyWindow *window)
 	g_object_set (action, "sensitive", !fullscreen, NULL);
 	action = gtk_action_group_get_action (action_group, "TabsDetach");
 	g_object_set (action, "sensitive", !fullscreen, NULL);
-
-	update_print_actions (window, TRUE);
 }
 
 static void
@@ -1095,7 +1120,7 @@ setup_ui_manager (EphyWindow *window)
 {
 	GtkActionGroup *action_group;
 	GtkAction *action;
-	GtkUIManager *merge;
+	GtkUIManager *manager;
 	GError *err = NULL;
 
 	window->priv->main_vbox = gtk_vbox_new (FALSE, 0);
@@ -1109,11 +1134,11 @@ setup_ui_manager (EphyWindow *window)
 			    GTK_WIDGET (window->priv->menu_dock),
 			    FALSE, TRUE, 0);
 
-	merge = gtk_ui_manager_new ();
+	manager = gtk_ui_manager_new ();
 
-	g_signal_connect (merge, "connect_proxy",
+	g_signal_connect (manager, "connect_proxy",
 			  G_CALLBACK (connect_proxy_cb), window);
-	g_signal_connect (merge, "disconnect_proxy",
+	g_signal_connect (manager, "disconnect_proxy",
 			  G_CALLBACK (disconnect_proxy_cb), window);
 
 	action_group = gtk_action_group_new ("WindowActions");
@@ -1124,7 +1149,7 @@ setup_ui_manager (EphyWindow *window)
 					     ephy_menu_toggle_entries,
 					     ephy_menu_n_toggle_entries,
 					     window);
-	gtk_ui_manager_insert_action_group (merge, action_group, 0);
+	gtk_ui_manager_insert_action_group (manager, action_group, 0);
 	window->priv->action_group = action_group;
 	action = gtk_action_group_get_action (action_group, "FileOpen");
 	g_object_set (action, "short_label", _("Open"), NULL);
@@ -1153,16 +1178,16 @@ setup_ui_manager (EphyWindow *window)
 	gtk_action_group_set_translation_domain (action_group, NULL);
 	gtk_action_group_add_actions (action_group, ephy_popups_entries,
 				      ephy_popups_n_entries, window);
-	gtk_ui_manager_insert_action_group (merge, action_group, 0);
+	gtk_ui_manager_insert_action_group (manager, action_group, 0);
 	window->priv->popups_action_group = action_group;
 
-	window->ui_merge = G_OBJECT (merge);
-	g_signal_connect (merge, "add_widget", G_CALLBACK (add_widget), window);
+	window->priv->manager = manager;
+	g_signal_connect (manager, "add_widget", G_CALLBACK (add_widget), window);
 	gtk_window_add_accel_group (GTK_WINDOW (window),
-				    gtk_ui_manager_get_accel_group (merge));
+				    gtk_ui_manager_get_accel_group (manager));
 
 	gtk_ui_manager_add_ui_from_file
-		(merge, ephy_file ("epiphany-ui.xml"), &err);
+		(manager, ephy_file ("epiphany-ui.xml"), &err);
 	if (err != NULL)
 	{
 		g_warning ("Could not merge epiphany-ui.xml: %s", err->message);
@@ -1296,8 +1321,8 @@ sync_tab_security (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 	EmbedSecurityLevel level;
 	char *description = NULL;
 	char *state = NULL;
-	gboolean secure;
 	char *tooltip;
+	const char *stock_id = STOCK_LOCK_INSECURE;
 
 	if (window->priv->closing) return;
 
@@ -1305,14 +1330,6 @@ sync_tab_security (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 
 	ephy_embed_get_security_level (embed, &level, &description);
 
-	if (level != ephy_tab_get_security_level (tab))
-	{
-		/* something is VERY wrong here! */
-		level = STATE_IS_UNKNOWN;
-		description = NULL;
-	}
-
-	secure = FALSE;
 	switch (level)
 	{
 		case STATE_IS_UNKNOWN:
@@ -1323,18 +1340,19 @@ sync_tab_security (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 			break;
 		case STATE_IS_BROKEN:
 			state = _("Broken");
+			stock_id = STOCK_LOCK_BROKEN;
 			break;
 		case STATE_IS_SECURE_MED:
 			state = _("Medium");
-			secure = TRUE;
+			stock_id = STOCK_LOCK_SECURE;
 			break;
 		case STATE_IS_SECURE_LOW:
 			state = _("Low");
-			secure = TRUE;
+			stock_id = STOCK_LOCK_SECURE;
 			break;
 		case STATE_IS_SECURE_HIGH:
 			state = _("High");
-			secure = TRUE;
+			stock_id = STOCK_LOCK_SECURE;
 			break;
 		default:
 			g_assert_not_reached ();
@@ -1354,7 +1372,7 @@ sync_tab_security (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 	}
 
 	ephy_statusbar_set_security_state (EPHY_STATUSBAR (window->priv->statusbar),
-					   secure, tooltip);
+					   stock_id, tooltip);
 	g_free (tooltip);
 
 }
@@ -1430,9 +1448,6 @@ sync_tab_load_status (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 	status = ephy_tab_get_load_status (tab);
 	g_object_set (action, "sensitive", status, NULL);
 
-	/* disable print while loading, see bug #116344 */
-	update_print_actions (window, !status);
-
 	if (status)
 	{
 		toolbar_spinner_start (window->priv->toolbar);
@@ -1571,6 +1586,116 @@ hide_embed_popup_cb (GtkWidget *popup,
 		(popup, G_CALLBACK (hide_embed_popup_cb), window);
 }
 
+static char *
+get_name_from_address_value (const GValue *value)
+{
+	GnomeVFSURI *uri;
+	char *name = NULL;
+
+	uri = gnome_vfs_uri_new (g_value_get_string (value));
+	if (uri)
+	{
+		name = gnome_vfs_uri_extract_short_name (uri);
+		gnome_vfs_uri_unref (uri);
+	}
+
+	return name;
+}
+
+static void
+update_popups_tooltips (EphyWindow *window, EphyEmbedEvent *event)
+{
+	EmbedEventContext context;
+	GtkActionGroup *group = window->priv->popups_action_group;
+	const GValue *value;
+	GtkAction *action;
+	char *tooltip, *name;
+
+	if (ephy_embed_event_has_property (event, "background_image"))
+	{
+		ephy_embed_event_get_property (event, "background_image", &value);
+
+		action = gtk_action_group_get_action (group, "SaveBackgroundAs");
+		name = get_name_from_address_value (value);
+		tooltip = g_strdup_printf (_("Save background image '%s'"), name);
+		g_object_set (action, "tooltip", tooltip, NULL);
+		g_free (name);
+		g_free (tooltip);
+	}
+
+	context = ephy_embed_event_get_context (event);
+
+	if (context & EMBED_CONTEXT_IMAGE)
+	{
+		ephy_embed_event_get_property (event, "image", &value);
+		name = get_name_from_address_value (value);
+
+		action = gtk_action_group_get_action (group, "OpenImage");
+		tooltip = g_strdup_printf (_("Open image '%s'"), name);
+		g_object_set (action, "tooltip", tooltip, NULL);
+		g_free (tooltip);
+
+		action = gtk_action_group_get_action (group, "SetImageAsBackground");
+		tooltip = g_strdup_printf (_("Use as desktop background '%s'"), name);
+		g_object_set (action, "tooltip", tooltip, NULL);
+		g_free (tooltip);
+
+		action = gtk_action_group_get_action (group, "SaveImageAs");
+		tooltip = g_strdup_printf (_("Save image '%s'"), name);
+		g_object_set (action, "tooltip", tooltip, NULL);
+		g_free (tooltip);
+
+		action = gtk_action_group_get_action (group, "CopyImageLocation");
+		tooltip = g_strdup_printf (_("Copy image address '%s'"),
+					   g_value_get_string (value));
+		g_object_set (action, "tooltip", tooltip, NULL);
+		g_free (tooltip);		
+
+		g_free (name);
+	}
+
+	if (context & EMBED_CONTEXT_EMAIL_LINK)
+	{
+		ephy_embed_event_get_property (event, "link", &value);
+
+		action = gtk_action_group_get_action (group, "SendEmail");
+		tooltip = g_strdup_printf (_("Send email to address '%s'"),
+					   g_value_get_string (value));
+		g_object_set (action, "tooltip", tooltip, NULL);
+		g_free (tooltip);
+
+		action = gtk_action_group_get_action (group, "CopyEmailAddress");
+		tooltip = g_strdup_printf (_("Copy email address '%s'"),
+					   g_value_get_string (value));
+		g_object_set (action, "tooltip", tooltip, NULL);
+		g_free (tooltip);
+	}
+
+	if (context & EMBED_CONTEXT_LINK)
+	{
+		ephy_embed_event_get_property (event, "link", &value);
+
+		action = gtk_action_group_get_action (group, "DownloadLink");
+		name = get_name_from_address_value (value);
+		tooltip = g_strdup_printf (_("Save link '%s'"), name);
+		g_object_set (action, "tooltip", tooltip, NULL);
+		g_free (name);
+		g_free (tooltip);
+
+		action = gtk_action_group_get_action (group, "BookmarkLink");
+		tooltip = g_strdup_printf (_("Bookmark link '%s'"),
+					   g_value_get_string (value));
+		g_object_set (action, "tooltip", tooltip, NULL);
+		g_free (tooltip);
+
+		action = gtk_action_group_get_action (group, "CopyLinkAddress");
+		tooltip = g_strdup_printf (_("Copy link's address '%s'"),
+					   g_value_get_string (value));
+		g_object_set (action, "tooltip", tooltip, NULL);
+		g_free (tooltip);
+	}
+}
+
 static void
 show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 {
@@ -1599,8 +1724,18 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 
 	LOG ("show_embed_popup context %x", context)
 
-	if ((context & EMBED_CONTEXT_LINK) &&
+	if ((context & EMBED_CONTEXT_EMAIL_LINK) &&
 	    (context & EMBED_CONTEXT_IMAGE))
+	{
+		popup = "/EphyImageEmailLinkPopup";
+	}
+	else if (context & EMBED_CONTEXT_EMAIL_LINK)
+	{
+		popup = "/EphyEmailLinkPopup";
+		update_edit_actions_sensitivity (window, TRUE);
+	}
+	else if ((context & EMBED_CONTEXT_LINK) &&
+		 (context & EMBED_CONTEXT_IMAGE))
 	{
 		popup = "/EphyImageLinkPopup";
 	}
@@ -1625,8 +1760,9 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 		update_edit_actions_sensitivity (window, TRUE);
 	}
 
-	widget = gtk_ui_manager_get_widget (GTK_UI_MANAGER (window->ui_merge),
-				            popup);
+	update_popups_tooltips (window, event);
+
+	widget = gtk_ui_manager_get_widget (window->priv->manager, popup);
 	g_return_if_fail (widget != NULL);
 
 	action_group = window->priv->popups_action_group;
@@ -2045,6 +2181,9 @@ ephy_window_set_property (GObject *object,
 		case PROP_CHROME:
 			ephy_window_set_chrome (window, g_value_get_flags (value));
 			break;
+		case PROP_PPV_MODE:
+			ephy_window_set_print_preview (window, g_value_get_boolean (value));
+			break;
 	}
 }
 
@@ -2064,9 +2203,38 @@ ephy_window_get_property (GObject *object,
 		case PROP_CHROME:
 			g_value_set_flags (value, window->priv->chrome);
 			break;
+		case PROP_PPV_MODE:
+			g_value_set_boolean (value, window->priv->ppv_mode);
+			break;
 	}
 }
 
+static gboolean
+ephy_window_focus_in_event (GtkWidget *widget, GdkEventFocus *event)
+{
+	EphyWindow *window = EPHY_WINDOW (widget);
+
+	if (window->priv->exit_fullscreen_popup)
+	{
+		gtk_widget_show (window->priv->exit_fullscreen_popup);
+	}
+
+	return GTK_WIDGET_CLASS (parent_class)->focus_in_event (widget, event);
+}
+
+static gboolean
+ephy_window_focus_out_event (GtkWidget *widget, GdkEventFocus *event)
+{
+	EphyWindow *window = EPHY_WINDOW (widget);
+
+	if (window->priv->exit_fullscreen_popup)
+	{
+		gtk_widget_hide (window->priv->exit_fullscreen_popup);
+	}
+
+	return GTK_WIDGET_CLASS (parent_class)->focus_out_event (widget, event);
+}
+
 static void
 ephy_window_class_init (EphyWindowClass *klass)
 {
@@ -2084,6 +2252,8 @@ ephy_window_class_init (EphyWindowClass *klass)
 
 	widget_class->show = ephy_window_show;
 	widget_class->key_press_event = ephy_window_key_press_event;
+	widget_class->focus_in_event = ephy_window_focus_in_event;
+	widget_class->focus_out_event = ephy_window_focus_out_event;
 
 	g_object_class_install_property (object_class,
 					 PROP_ACTIVE_TAB,
@@ -2103,41 +2273,15 @@ ephy_window_class_init (EphyWindowClass *klass)
 							     G_PARAM_CONSTRUCT_ONLY |
 							     G_PARAM_READWRITE));
 
-	g_type_class_add_private (object_class, sizeof(EphyWindowPrivate));
-}
+	g_object_class_install_property (object_class,
+					 PROP_PPV_MODE,
+					 g_param_spec_boolean ("print-preview-mode",
+							       "Print preview mode",
+							       "Whether the window is in print preview mode",
+							       FALSE,
+							       G_PARAM_READWRITE));
 
-static void
-ensure_default_icon (void)
-{
-	static gboolean ephy_has_default_icon = FALSE;
-	GtkIconTheme *icon_theme;
-	GtkIconInfo *icon_info;
-	const char *icon_file;
-
-	if (ephy_has_default_icon) return;
-
-	/* FIXME listen on icon changes */
-	/* FIXME MultiHead: icon theme is per-display, not global */
-	icon_theme = gtk_icon_theme_get_default ();
-	icon_info = gtk_icon_theme_lookup_icon (icon_theme, "web-browser", -1, 0);
-
-	if (icon_info)
-	{
-
-		icon_file = gtk_icon_info_get_filename (icon_info);
-		if (icon_file)
-		{
-			gtk_window_set_default_icon_from_file (icon_file, NULL);
-		}
-
-		gtk_icon_info_free (icon_info);
-	}
-	else
-	{
-		g_warning ("Web browser gnome icon not found");
-	}
-
-	ephy_has_default_icon = TRUE;
+	g_type_class_add_private (object_class, sizeof (EphyWindowPrivate));
 }
 
 static void
@@ -2212,6 +2356,15 @@ action_request_forward_cb (GObject *toolbar,
 	g_signal_emit_by_name (bookmarksbar, "action_request", name);
 }
 
+static void
+open_bookmark_cb (EphyBookmarksMenu *menu,
+		  const char *location,
+		  gboolean open_in_new,
+		  EphyWindow *window)
+{
+	ephy_window_load_url (window, location);
+}
+
 static void
 ephy_window_init (EphyWindow *window)
 {
@@ -2223,18 +2376,7 @@ ephy_window_init (EphyWindow *window)
 
 	window->priv = EPHY_WINDOW_GET_PRIVATE (window);
 
-	window->priv->active_tab = NULL;
-	window->priv->closing = FALSE;
-	window->priv->ppview_toolbar = NULL;
-	window->priv->exit_fullscreen_popup = NULL;
-	window->priv->num_tabs = 0;
-	window->priv->has_size = FALSE;
 	window->priv->chrome = EPHY_EMBED_CHROME_ALL;
-	window->priv->should_save_chrome = FALSE;
-	window->priv->fullscreen_mode = FALSE;
-	window->priv->ppv_mode = FALSE;
-
-	ensure_default_icon ();
 
 	g_object_ref (ephy_shell);
 
@@ -2248,9 +2390,9 @@ ephy_window_init (EphyWindow *window)
 	gtk_widget_show (GTK_WIDGET (window->priv->notebook));
 
 	window->priv->statusbar = ephy_statusbar_new ();
-	gtk_box_pack_start (GTK_BOX (window->priv->main_vbox),
-			    GTK_WIDGET (window->priv->statusbar),
-			    FALSE, TRUE, 0);
+	gtk_box_pack_end (GTK_BOX (window->priv->main_vbox),
+			  GTK_WIDGET (window->priv->statusbar),
+			  FALSE, TRUE, 0);
 	window->priv->tab_message_cid = gtk_statusbar_get_context_id
 		(GTK_STATUSBAR (window->priv->statusbar), "tab_message");
 	window->priv->help_message_cid = gtk_statusbar_get_context_id
@@ -2260,7 +2402,11 @@ ephy_window_init (EphyWindow *window)
 	window->priv->tabs_menu = ephy_tabs_menu_new (window);
 	window->priv->fav_menu = ephy_favorites_menu_new (window);
 	window->priv->enc_menu = ephy_encoding_menu_new (window);
-	window->priv->bmk_menu = ephy_bookmarks_menu_new (window);
+
+	window->priv->bmk_menu = ephy_bookmarks_menu_new (window->priv->manager,
+							  BOOKMARKS_MENU_PATH);
+	g_signal_connect (window->priv->bmk_menu, "open",
+			  G_CALLBACK (open_bookmark_cb), window);
 
 	/* get the toolbars model *before* getting the bookmarksbar model
 	 * (via ephy_bookmarsbar_new()), so that the toolbars model is
@@ -2368,7 +2514,7 @@ ephy_window_init (EphyWindow *window)
 			  G_CALLBACK (network_status_changed), window);
 
 	/* ensure the UI is updated */
-	gtk_ui_manager_ensure_update (GTK_UI_MANAGER (window->ui_merge));
+	gtk_ui_manager_ensure_update (window->priv->manager);
 
 	init_menu_updaters (window);
 }
@@ -2410,7 +2556,7 @@ ephy_window_finalize (GObject *object)
 	}
 
 	g_object_unref (window->priv->action_group);
-	g_object_unref (window->ui_merge);
+	g_object_unref (window->priv->manager);
 
         G_OBJECT_CLASS (parent_class)->finalize (object);
 
@@ -2461,7 +2607,7 @@ ephy_window_set_print_preview (EphyWindow *window, gboolean enabled)
 {
 	GtkAccelGroup *accel_group;
 
-	accel_group = gtk_ui_manager_get_accel_group (GTK_UI_MANAGER (window->ui_merge));
+	accel_group = gtk_ui_manager_get_accel_group (window->priv->manager);
 
 	if (window->priv->ppv_mode == enabled) return;
 
@@ -2485,6 +2631,24 @@ ephy_window_set_print_preview (EphyWindow *window, gboolean enabled)
 		window->priv->ppview_toolbar = NULL;
 		gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
 	}
+
+	g_object_notify (G_OBJECT (window), "print-preview-mode");
+}
+
+/**
+ * ephy_window_get_ui_manager:
+ * @window: an #EphyWindow
+ *
+ * Returns this window's UI manager.
+ *
+ * Return value: an #GtkUIManager
+ **/
+GObject *
+ephy_window_get_ui_manager (EphyWindow *window)
+{
+	g_return_val_if_fail (EPHY_IS_WINDOW (window), NULL);
+
+	return G_OBJECT (window->priv->manager);
 }
 
 /**
@@ -2680,12 +2844,6 @@ ephy_window_activate_location (EphyWindow *window)
 	toolbar_activate_location (window->priv->toolbar);
 }
 
-/**
- * ephy_window_show:
- * @widget: an #EphyWindow
- *
- * Shows @widget if it is hidden.
- **/
 static void
 ephy_window_show (GtkWidget *widget)
 {
@@ -2874,11 +3032,12 @@ ephy_window_set_zoom (EphyWindow *window,
 void
 ephy_window_load_in_tabs (EphyWindow *window,
 			  EphyTab *tab,
-			  GList *uri_list)
+			  char **uris)
 {
 	EphyEmbed *embed = NULL;
-	GList *l;
-	guint num = 0;
+	guint num;
+
+	g_return_if_fail (uris != NULL);
 
 	if (tab != NULL)
 	{
@@ -2886,11 +3045,10 @@ ephy_window_load_in_tabs (EphyWindow *window,
 		g_return_if_fail (EPHY_IS_EMBED (embed));
 	}
 
-	l = uri_list;
-	while (l != NULL && num < INSANE_NUMBER_OF_URLS)
+	for (num = 0; uris[num] != NULL && num < INSANE_NUMBER_OF_URLS; num++)
 	{
-		const char *url = l->data;
-
+		const char *url = uris[num];
+	
 		if (num == 0 && embed != NULL)
 		{
 			/**
@@ -2908,9 +3066,6 @@ ephy_window_load_in_tabs (EphyWindow *window,
 						  (tab ? EPHY_NEW_TAB_APPEND_AFTER :
 							 EPHY_NEW_TAB_APPEND_LAST));
 		}
-
-		l = l->next;
-		++num;
 	}
 }
 
